% Auto-generated chapter 96 for bukhari
% Hadiths in this chapter: 97

\hadithdefcmd{bukhari}{7268}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، وَغَيْرِهِ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَ قَالَ رَجُلٌ مِنَ الْيَهُودِ لِعُمَرَ يَا أَمِيرَ الْمُؤْمِنِينَ لَوْ أَنَّ عَلَيْنَا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ الْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ وَأَتْمَمْتُ عَلَيْكُمْ نِعْمَتِي وَرَضِيتُ لَكُمُ الإِسْلاَمَ دِينًا‏\}‏ لاَتَّخَذْنَا ذَلِكَ الْيَوْمَ عِيدًا‏.‏ فَقَالَ عُمَرُ إِنِّي لأَعْلَمُ أَىَّ يَوْمٍ نَزَلَتْ هَذِهِ الآيَةُ، نَزَلَتْ يَوْمَ عَرَفَةَ فِي يَوْمِ جُمُعَةٍ‏.‏ سَمِعَ سُفْيَانُ مِنْ مِسْعَرٍ وَمِسْعَرٌ قَيْسًا وَقَيْسٌ طَارِقًا‏.‏\hadithno{7268}\hadithtrans{Narrated Tariq bin Shihab:A Jew said to `Umar, "O Chief of the Believers, if this verse: 'This day I have perfected your religion for you, completed My favors upon you, and have chosen for you, Islam as your religion.' (5.3) had been revealed upon us, we would have taken that day as an `Id (festival) day." `Umar said, "I know definitely on what day this Verse was revealed; it was revealed on the day of `Arafat, on a Friday}}
\hadithdefcmd{bukhari}{7269}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّهُ سَمِعَ عُمَرَ الْغَدَ، حِينَ بَايَعَ الْمُسْلِمُونَ أَبَا بَكْرٍ، وَاسْتَوَى عَلَى مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَشَهَّدَ قَبْلَ أَبِي بَكْرٍ فَقَالَ أَمَّا بَعْدُ فَاخْتَارَ اللَّهُ لِرَسُولِهِ صلى الله عليه وسلم الَّذِي عِنْدَهُ عَلَى الَّذِي عِنْدَكُمْ، وَهَذَا الْكِتَابُ الَّذِي هَدَى اللَّهُ بِهِ رَسُولَكُمْ فَخُذُوا بِهِ تَهْتَدُوا وَإِنَّمَا هَدَى اللَّهُ بِهِ رَسُولَهُ‏.‏\hadithno{7269}\hadithtrans{Narrated Anas bin Malik:That he heard `Umar speaking while standing on the pulpit of the Prophet (ﷺ) in the morning (following the death of the Prophet), when the people had sworn allegiance to Abu Bakr. He said the Tashah-hud before Abu Bakr, and said, "Amma Ba'du (then after) Allah has chosen for his Apostle what is with Him (Paradise) rather than what is with you (the world). This is that Book (Qur'an) with which Allah guided your Apostle, so stick to it, for then you will be guided on the right path as Allah guided His Apostle with it}}
\hadithdefcmd{bukhari}{7270}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ضَمَّنِي إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏ "‏ اللَّهُمَّ عَلِّمْهُ الْكِتَابَ ‏"‏‏.‏\hadithno{7270}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) embraced me and said, "O Allah! Teach him (the knowledge of) the Book (Qur'an)}}
\hadithdefcmd{bukhari}{7271}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ صَبَّاحٍ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ عَوْفًا، أَنَّ أَبَا الْمِنْهَالِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا بَرْزَةَ، قَالَ إِنَّ اللَّهَ يُغْنِيكُمْ أَوْ نَغَشَكُمْ بِالإِسْلاَمِ وَبِمُحَمَّدٍ صلى الله عليه وسلم‏.‏ قَالَ أَبُو عَبْد اللَّهِ وَقَعَ هَاهُنَا يُغْنِيكُمْ وَإِنَّمَا هُوَ نَعَشَكُمْ يُنْظَرُ فِي أَصْلِ كِتَابِ الِاعْتِصَامِ\hadithno{7271}\hadithtrans{Narrated Abal Minhal:Abu Barza said, "(O people!) Allah makes you self-sufficient or has raised you high with Islam and with Muhammad}}
\hadithdefcmd{bukhari}{7272}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَتَبَ إِلَى عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ يُبَايِعُهُ، وَأُقِرُّ لَكَ بِالسَّمْعِ وَالطَّاعَةِ عَلَى سُنَّةِ اللَّهِ وَسُنَّةِ رَسُولِهِ، فِيمَا اسْتَطَعْتُ‏.‏\hadithno{7272}\hadithtrans{Narrated `Abdullah bin Dinar:`Abdullah Bin `Umar wrote to `Abdul Malik bin Marwan, swearing allegiance to him: 'I swear allegiance to you in that I will listen and obey what is in accordance with the Laws of Allah and the Tradition of His Apostle as much as I can}}
\hadithdefcmd{bukhari}{7273}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ بِجَوَامِعِ الْكَلِمِ، وَنُصِرْتُ بِالرُّعْبِ، وَبَيْنَا أَنَا نَائِمٌ رَأَيْتُنِي أُتِيتُ بِمَفَاتِيحِ خَزَائِنِ الأَرْضِ، فَوُضِعَتْ فِي يَدِي ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ فَقَدْ ذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمْ تَلْغَثُونَهَا أَوْ تَرْغَثُونَهَا، أَوْ كَلِمَةً تُشْبِهُهَا‏.‏\hadithno{7273}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:Abu Huraira said that Allah's Messenger (ﷺ) said, "I have been sent with 'Jawami-al-Kalim ' (the shortest expression with the widest meaning) and have been made victorious with awe (cast in my enemy's hearts), and while I was sleeping, I saw that the keys of the treasures of the world were placed in my hand." Abu Huraira added: Allah's Messenger (ﷺ) has gone, and you people are utilizing those treasures, or digging those treasures out." or said a similar sentence}}
\hadithdefcmd{bukhari}{7274}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنَ الأَنْبِيَاءِ نَبِيٌّ إِلاَّ أُعْطِيَ مِنَ الآيَاتِ مَا مِثْلُهُ أُومِنَ ـ أَوْ آمَنَ ـ عَلَيْهِ الْبَشَرُ، وَإِنَّمَا كَانَ الَّذِي أُوتِيتُ وَحْيًا أَوْحَاهُ اللَّهُ إِلَىَّ، فَأَرْجُو أَنِّي أَكْثَرُهُمْ تَابِعًا يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{7274}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There was no prophet among the prophets but was given miracles because of which people had security or had belief, but what I was given was the Divine Inspiration which Allah revealed to me. So I hope that my followers will be more than those of any other prophet on the Day of Resurrection}}
\hadithdefcmd{bukhari}{7275}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، قَالَ جَلَسْتُ إِلَى شَيْبَةَ فِي هَذَا الْمَسْجِدِ قَالَ جَلَسَ إِلَىَّ عُمَرُ فِي مَجْلِسِكَ هَذَا فَقَالَ هَمَمْتُ أَنْ لاَ أَدَعَ فِيهَا صَفْرَاءَ وَلاَ بَيْضَاءَ إِلاَّ قَسَمْتُهَا بَيْنَ الْمُسْلِمِينَ‏.‏ قُلْتُ مَا أَنْتَ بِفَاعِلٍ‏.‏ قَالَ لِمَ‏.‏ قُلْتُ لَمْ يَفْعَلْهُ صَاحِبَاكَ قَالَ هُمَا الْمَرْآنِ يُقْتَدَى بِهِمَا‏.‏\hadithno{7275}\hadithtrans{Narrated Abu Wail:I sat with Shaiba in this Mosque (Al-Masjid-Al-Haram), and he said, "`Umar once sat beside me here as you are now sitting, and said, 'I feel like distributing all the gold and silver that are in it (i.e., the Ka`ba) among the Muslims'. I said, 'You cannot do that.' `Umar said, 'Why?' I said, 'Your two (previous) companions (the Prophet (ﷺ) and Abu Bakr) did not do it. `Umar said, 'They are the two persons whom one must follow.'" (See Hadith No. 664, Vol)}}
\hadithdefcmd{bukhari}{7276}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَأَلْتُ الأَعْمَشَ فَقَالَ عَنْ زَيْدِ بْنِ وَهْبٍ، سَمِعْتُ حُذَيْفَةَ، يَقُولُ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ الأَمَانَةَ نَزَلَتْ مِنَ السَّمَاءِ فِي جَذْرِ قُلُوبِ الرِّجَالِ، وَنَزَلَ الْقُرْآنُ فَقَرَءُوا الْقُرْآنَ وَعَلِمُوا مِنَ السُّنَّةِ ‏"‏‏.‏\hadithno{7276}\hadithtrans{Narrated Hudhaifa:Allah's Messenger (ﷺ) said to us, "Honesty descended from the Heavens and settled in the roots of the hearts of men (faithful believers), and then the Qur'an was revealed and the people read the Qur'an, (and learnt it from it) and also learnt it from the Sunna." Both Qur'an and Sunna strengthened their (the faithful believers') honesty. (See Hadith No)}}
\hadithdefcmd{bukhari}{7277}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا عَمْرُو بْنُ مُرَّةَ، سَمِعْتُ مُرَّةَ الْهَمْدَانِيَّ، يَقُولُ قَالَ عَبْدُ اللَّهِ إِنَّ أَحْسَنَ الْحَدِيثِ كِتَابُ اللَّهِ، وَأَحْسَنَ الْهَدْىِ هَدْىُ مُحَمَّدٍ صلى الله عليه وسلم، وَشَرَّ الأُمُورِ مُحْدَثَاتُهَا، وَإِنَّ مَا تُوعَدُونَ لآتٍ، وَمَا أَنْتُمْ بِمُعْجِزِينَ‏.‏\hadithno{7277}\hadithtrans{Narrated `Abdullah:The best talk (speech) is Allah's Book 'Qur'an), and the best way is the way of Muhammad, and the worst matters are the heresies (those new things which are introduced into the religion); and whatever you have been promised will surely come to pass, and you cannot escape (it)}}
\hadithdefcmd{bukhari}{7279}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ، قَالاَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ ‏"‏‏.‏\hadithno{7279}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:We were with the Prophet (ﷺ) when he said (to two men), "I shall judge between you according to Allah's Book (Laws)}}
\hadithdefcmd{bukhari}{7280}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ كُلُّ أُمَّتِي يَدْخُلُونَ الْجَنَّةَ، إِلاَّ مَنْ أَبَى ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَنْ يَأْبَى قَالَ ‏"‏ مَنْ أَطَاعَنِي دَخَلَ الْجَنَّةَ، وَمَنْ عَصَانِي فَقَدْ أَبَى ‏"‏‏.‏\hadithno{7280}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "All my followers will enter Paradise except those who refuse." They said, "O Allah's Messenger (ﷺ)! Who will refuse?" He said, "Whoever obeys me will enter Paradise, and whoever disobeys me is the one who refuses (to enter it)}}
\hadithdefcmd{bukhari}{7281}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ، أَخْبَرَنَا يَزِيدُ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ ـ وَأَثْنَى عَلَيْهِ ـ حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، حَدَّثَنَا أَوْ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ جَاءَتْ مَلاَئِكَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ نَائِمٌ فَقَالَ بَعْضُهُمْ إِنَّهُ نَائِمٌ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّ الْعَيْنَ نَائِمَةٌ وَالْقَلْبَ يَقْظَانُ‏.‏ فَقَالُوا إِنَّ لِصَاحِبِكُمْ هَذَا مَثَلاً فَاضْرِبُوا لَهُ مَثَلاً‏.‏ فَقَالَ بَعْضُهُمْ إِنَّهُ نَائِمٌ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّ الْعَيْنَ نَائِمَةٌ وَالْقَلْبَ يَقْظَانُ‏.‏ فَقَالُوا مَثَلُهُ كَمَثَلِ رَجُلٍ بَنَى دَارًا، وَجَعَلَ فِيهَا مَأْدُبَةً وَبَعَثَ دَاعِيًا، فَمَنْ أَجَابَ الدَّاعِيَ دَخَلَ الدَّارَ وَأَكَلَ مِنَ الْمَأْدُبَةِ، وَمَنْ لَمْ يُجِبِ الدَّاعِيَ لَمْ يَدْخُلِ الدَّارَ وَلَمْ يَأْكُلْ مِنَ الْمَأْدُبَةِ‏.‏ فَقَالُوا أَوِّلُوهَا لَهُ يَفْقَهْهَا فَقَالَ بَعْضُهُمْ إِنَّهُ نَائِمٌ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّ الْعَيْنَ نَائِمَةٌ وَالْقَلْبَ يَقْظَانُ‏.‏ فَقَالُوا فَالدَّارُ الْجَنَّةُ، وَالدَّاعِي مُحَمَّدٌ صلى الله عليه وسلم فَمَنْ أَطَاعَ مُحَمَّدًا صلى الله عليه وسلم فَقَدْ أَطَاعَ اللَّهَ، وَمَنْ عَصَى مُحَمَّدًا صلى الله عليه وسلم فَقَدْ عَصَى اللَّهَ، وَمُحَمَّدٌ صلى الله عليه وسلم فَرْقٌ بَيْنَ النَّاسِ‏.‏ تَابَعَهُ قُتَيْبَةُ عَنْ لَيْثٍ، عَنْ خَالِدٍ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ جَابِرٍ، خَرَجَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{7281}\hadithtrans{Narrated Jabir bin `Abdullah:Some angels came to the Prophet (ﷺ) while he was sleeping. Some of them said, "He is sleeping." Others said, "His eyes are sleeping but his heart is awake." Then they said, "There is an example for this companion of yours." One of them said, "Then set forth an example for him." Some of them said, "He is sleeping." The others said, "His eyes are sleeping but his heart is awake." Then they said, "His example is that of a man who has built a house and then offered therein a banquet and sent an inviter (messenger) to invite the people. So whoever accepted the invitation of the inviter, entered the house and ate of the banquet, and whoever did not accept the invitation of the inviter, did not enter the house, nor did he eat of the banquet." Then the angels said, "Interpret this example to him so that he may understand it." Some of them said, "He is sleeping.'' The others said, "His eyes are sleeping but his heart is awake." And then they said, "The houses stands for Paradise and the call maker is Muhammad; and whoever obeys Muhammad, obeys Allah; and whoever disobeys Muhammad, disobeys Allah. Muhammad separated the people (i.e., through his message, the good is distinguished from the bad, and the believers from the disbelievers)}}
\hadithdefcmd{bukhari}{7282}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ حُذَيْفَةَ، قَالَ يَا مَعْشَرَ الْقُرَّاءِ اسْتَقِيمُوا فَقَدْ سُبِقْتُمْ سَبْقًا بَعِيدًا فَإِنْ أَخَذْتُمْ يَمِينًا وَشِمَالاً، لَقَدْ ضَلَلْتُمْ ضَلاَلاً بَعِيدًا‏.‏\hadithno{7282}\hadithtrans{Narrated Hammam:Hudhaifa said, "O the Group of Al-Qurra! Follow the straight path, for then you have taken a great lead (and will be the leaders), but if you divert right or left, then you will go astray far away}}
\hadithdefcmd{bukhari}{7283}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلِي وَمَثَلُ مَا بَعَثَنِي اللَّهُ بِهِ كَمَثَلِ رَجُلٍ أَتَى قَوْمًا فَقَالَ يَا قَوْمِ إِنِّي رَأَيْتُ الْجَيْشَ بِعَيْنَىَّ، وَإِنِّي أَنَا النَّذِيرُ الْعُرْيَانُ فَالنَّجَاءَ‏.‏ فَأَطَاعَهُ طَائِفَةٌ مِنْ قَوْمِهِ فَأَدْلَجُوا، فَانْطَلَقُوا عَلَى مَهَلِهِمْ فَنَجَوْا، وَكَذَّبَتْ طَائِفَةٌ مِنْهُمْ فَأَصْبَحُوا مَكَانَهُمْ، فَصَبَّحَهُمُ الْجَيْشُ، فَأَهْلَكَهُمْ وَاجْتَاحَهُمْ، فَذَلِكَ مَثَلُ مَنْ أَطَاعَنِي، فَاتَّبَعَ مَا جِئْتُ بِهِ، وَمَثَلُ مَنْ عَصَانِي وَكَذَّبَ بِمَا جِئْتُ بِهِ مِنَ الْحَقِّ ‏"‏‏.‏\hadithno{7283}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "My example and the example of what I have been sent with is that of a man who came to some people and said, 'O people! I have seen the enemy's army with my own eyes, and I am the naked warner; so protect yourselves!' Then a group of his people obeyed him and fled at night proceeding stealthily till they were safe, while another group of them disbelieved him and stayed at their places till morning when the army came upon them, and killed and ruined them completely So this is the example of that person who obeys me and follows what I have brought (the Qur'an and the Sunna), and the example of the one who disobeys me and disbelieves the truth I have brought}}
\hadithdefcmd{bukhari}{7285}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ بَعْدَهُ، وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ لأَبِي بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ، وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ، إِلاَّ بِحَقِّهِ، وَحِسَابُهُ عَلَى اللَّهِ ‏"‏‏.‏ فَقَالَ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ، فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ، وَاللَّهِ لَوْ مَنَعُونِي عِقَالاً كَانُوا يُؤَدُّونَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهِ‏.‏ فَقَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ قَدْ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ‏.‏ قَالَ ابْنُ بُكَيْرٍ وَعَبْدُ اللَّهِ عَنِ اللَّيْثِ عَنَاقًا‏.‏ وَهْوَ أَصَحُّ‏.‏\hadithno{7285}\hadithtrans{Narrated Abu Huraira:When Allah's Messenger (ﷺ) died and Abu Bakr was elected as a Caliph after him, some of the Arabs reverted to disbelief, `Umar said to Abu Bakr, "How dare you fight the people while Allah's Messenger (ﷺ) said, I have been ordered to fight the people till they say 'None has the right to be worshipped but Allah' And whoever says: None has the right to be worshipped but Allah.' waves his wealth and his life from me unless he deserves a legal punishment lusty, and his account will be with Allah! Abu Bakr said, "By Allah, I will fight him who discriminates between Zakat and prayers, for Zakat is the Compulsory right to be taken from the wealth By Allah, if they refuse to give me even a tying rope which they use to give to Allah's Messenger (ﷺ), I would fight them for withholding it." `Umar said, 'By Allah, It was nothing, except I saw that Allah had opened the chest of Abu Bakr to the fight, and I came to know for certain that was the truth}}
\hadithdefcmd{bukhari}{7286}{حَدَّثَنِي إِسْمَاعِيلُ، حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ عُيَيْنَةُ بْنُ حِصْنِ بْنِ حُذَيْفَةَ بْنِ بَدْرٍ فَنَزَلَ عَلَى ابْنِ أَخِيهِ الْحُرِّ بْنِ قَيْسِ بْنِ حِصْنٍ، وَكَانَ مِنَ النَّفَرِ الَّذِينَ يُدْنِيهِمْ عُمَرُ، وَكَانَ الْقُرَّاءُ أَصْحَابَ مَجْلِسِ عُمَرَ وَمُشَاوَرَتِهِ كُهُولاً كَانُوا أَوْ شُبَّانًا فَقَالَ عُيَيْنَةُ لاِبْنِ أَخِيهِ يَا ابْنَ أَخِي هَلْ لَكَ وَجْهٌ عِنْدَ هَذَا الأَمِيرِ فَتَسْتَأْذِنَ لِي عَلَيْهِ قَالَ سَأَسْتَأْذِنُ لَكَ عَلَيْهِ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَاسْتَأْذَنَ لِعُيَيْنَةَ فَلَمَّا دَخَلَ قَالَ يَا ابْنَ الْخَطَّابِ وَاللَّهِ مَا تُعْطِينَا الْجَزْلَ، وَمَا تَحْكُمُ بَيْنَنَا بِالْعَدْلِ‏.‏ فَغَضِبَ عُمَرُ حَتَّى هَمَّ بِأَنْ يَقَعَ بِهِ فَقَالَ الْحُرُّ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ اللَّهَ تَعَالَى قَالَ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏خُذِ الْعَفْوَ وَأْمُرْ بِالْعُرْفِ وَأَعْرِضْ عَنِ الْجَاهِلِينَ‏\}‏ وَإِنَّ هَذَا مِنَ الْجَاهِلِينَ‏.‏ فَوَاللَّهِ مَا جَاوَزَهَا عُمَرُ حِينَ تَلاَهَا عَلَيْهِ، وَكَانَ وَقَّافًا عِنْدَ كِتَابِ اللَّهِ‏.‏\hadithno{7286}\hadithtrans{Narrated `Abdullah bin `Abbas:Uyaina bin Hisn bin Hudhaifa bin Badr came and stayed (at Medina) with his nephew Al-Hurr bin Qais bin Hisn who was one of those whom `Umar used to keep near him, as the Qurra' (learned men knowing Qur'an by heart) were the people of `Umar's meetings and his advisors whether they were old or young. 'Uyaina said to his nephew, "O my nephew! Have you an approach to this chief so as to get for me the permission to see him?" His nephew said, "I will get the permission for you to see him." (Ibn `Abbas added: ) So he took the permission for 'Uyaina, and when the latter entered, he said, "O the son of Al-Khattab! By Allah, you neither give us sufficient provision nor judge among us with justice." On that `Umar became so furious that he intended to harm him. Al-Hurr, said, "O Chief of the Believers!" Allah said to His Apostle 'Hold to forgiveness, command what is good (right), and leave the foolish (i.e. do not punish them).' (7.199) and this person is among the foolish." By Allah, `Umar did not overlook that Verse when Al-Hurr recited it before him, and `Umar said to observe (the orders of) Allah's Book strictly." (See Hadith No. 166, Vol)}}
\hadithdefcmd{bukhari}{7287}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ ابْنَةِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَنَّهَا قَالَتْ أَتَيْتُ عَائِشَةَ حِينَ خَسَفَتِ الشَّمْسُ، وَالنَّاسُ قِيَامٌ وَهْىَ قَائِمَةٌ تُصَلِّي فَقُلْتُ مَا لِلنَّاسِ فَأَشَارَتْ بِيَدِهَا نَحْوَ السَّمَاءِ فَقَالَتْ سُبْحَانَ اللَّهِ‏.‏ فَقُلْتُ آيَةٌ‏.‏ قَالَتْ بِرَأْسِهَا أَنْ نَعَمْ‏.‏ فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ مَا مِنْ شَىْءٍ لَمْ أَرَهُ إِلاَّ وَقَدْ رَأَيْتُهُ فِي مَقَامِي، حَتَّى الْجَنَّةَ وَالنَّارَ، وَأُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ قَرِيبًا مِنْ فِتْنَةِ الدَّجَّالِ، فَأَمَّا الْمُؤْمِنُ ـ أَوِ الْمُسْلِمُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ فَيَقُولُ مُحَمَّدٌ جَاءَنَا بِالْبَيِّنَاتِ فَأَجَبْنَا وَآمَنَّا‏.‏ فَيُقَالُ نَمْ صَالِحًا عَلِمْنَا أَنَّكَ مُوقِنٌ‏.‏ وَأَمَّا الْمُنَافِقُ ـ أَوِ الْمُرْتَابُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ فَيَقُولُ لاَ أَدْرِي سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُهُ ‏"‏‏.‏\hadithno{7287}\hadithtrans{Narrated Asma' bint Abu Bakr:I came to `Aisha during the solar eclipse. The people were standing (offering prayer) and she too, was standing and offering prayer. I asked, "What is wrong with the people?" She pointed towards the sky with her hand and said, Subhan Allah!'' I asked her, "Is there a sign?" She nodded with her head meaning, yes. When Allah's Messenger (ﷺ) finished (the prayer), he glorified and praised Allah and said, "There is not anything that I have not seen before but I have seen now at this place of mine, even Paradise and Hell. It has been revealed to me that you people will be put to trial nearly like the trial of Ad-Dajjal, in your graves. As for the true believer or a Muslim (the sub-narrator is not sure as to which of the two (words Asma' had said) he will say, 'Muhammad came with clear signs from Allah, and we responded to him (accepted his teachings) and believed (what he said)' It will be said (to him) 'Sleep in peace; we have known that you were a true believer who believed with certainty.' As for a hypocrite or a doubtful person, (the sub-narrator is not sure as to which word Asma' said) he will say, 'I do not know, but I heard the people saying something and so I said the same}}
\hadithdefcmd{bukhari}{7288}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ دَعُونِي مَا تَرَكْتُكُمْ، إِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ بِسُؤَالِهِمْ وَاخْتِلاَفِهِمْ عَلَى أَنْبِيَائِهِمْ، فَإِذَا نَهَيْتُكُمْ عَنْ شَىْءٍ فَاجْتَنِبُوهُ، وَإِذَا أَمَرْتُكُمْ بِأَمْرٍ فَأْتُوا مِنْهُ مَا اسْتَطَعْتُمْ ‏"‏‏.‏\hadithno{7288}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Leave me as I leave you, for the people who were before you were ruined because of their questions and their differences over their prophets. So, if I forbid you to do something, then keep away from it. And if I order you to do something, then do of it as much as you can}}
\hadithdefcmd{bukhari}{7289}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدٌ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَعْظَمَ الْمُسْلِمِينَ جُرْمًا مَنْ سَأَلَ عَنْ شَىْءٍ لَمْ يُحَرَّمْ، فَحُرِّمَ مِنْ أَجْلِ مَسْأَلَتِهِ ‏"‏‏.‏\hadithno{7289}\hadithtrans{Narrated Sa`d bin Abi Waqqas:The Prophet (ﷺ) said, "The most sinful person among the Muslims is the one who asked about something which had not been prohibited, but was prohibited because of his asking}}
\hadithdefcmd{bukhari}{7290}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَفَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، سَمِعْتُ أَبَا النَّضْرِ، يُحَدِّثُ عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اتَّخَذَ حُجْرَةً فِي الْمَسْجِدِ مِنْ حَصِيرٍ، فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا لَيَالِيَ، حَتَّى اجْتَمَعَ إِلَيْهِ نَاسٌ، ثُمَّ فَقَدُوا صَوْتَهُ لَيْلَةً فَظَنُّوا أَنَّهُ قَدْ نَامَ، فَجَعَلَ بَعْضُهُمْ يَتَنَحْنَحُ لِيَخْرُجَ إِلَيْهِمْ فَقَالَ ‏ "‏ مَا زَالَ بِكُمُ الَّذِي رَأَيْتُ مِنْ صَنِيعِكُمْ، حَتَّى خَشِيتُ أَنْ يُكْتَبَ عَلَيْكُمْ، وَلَوْ كُتِبَ عَلَيْكُمْ مَا قُمْتُمْ بِهِ فَصَلُّوا أَيُّهَا النَّاسُ فِي بُيُوتِكُمْ، فَإِنَّ أَفْضَلَ صَلاَةِ الْمَرْءِ فِي بَيْتِهِ، إِلاَّ الصَّلاَةَ الْمَكْتُوبَةَ ‏"‏‏.‏\hadithno{7290}\hadithtrans{Narrated Zaid bin Thabit:The Prophet (ﷺ) took a room made of date palm leaves mats in the mosque. Allah's Messenger (ﷺ) prayed in it for a few nights till the people gathered (to pray the night prayer (Tarawih) (behind him.) Then on the 4th night the people did not hear his voice and they thought he had slept, so some of them started humming in order that he might come out. The Prophet (ﷺ) then said, "You continued doing what I saw you doing till I was afraid that this (Tarawih prayer) might be enjoined on you, and if it were enjoined on you, you would not continue performing it. Therefore, O people! Perform your prayers at your homes, for the best prayer of a person is what is performed at his home except the compulsory congregational) prayer." (See Hadith No. 229,Vol. 3) (See Hadith No. 134, Vol)}}
\hadithdefcmd{bukhari}{7291}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَشْيَاءَ كَرِهَهَا، فَلَمَّا أَكْثَرُوا عَلَيْهِ الْمَسْأَلَةَ غَضِبَ وَقَالَ ‏"‏ سَلُونِي ‏"‏‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏‏.‏ ثُمَّ قَامَ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ مَنْ أَبِي فَقَالَ ‏"‏ أَبُوكَ سَالِمٌ مَوْلَى شَيْبَةَ ‏"‏‏.‏ فَلَمَّا رَأَى عُمَرُ مَا بِوَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْغَضَبِ قَالَ إِنَّا نَتُوبُ إِلَى اللَّهِ عَزَّ وَجَلَّ‏.‏\hadithno{7291}\hadithtrans{Narrated Abu Musa Al-Ash`ari:Allah's Messenger (ﷺ) was asked about things which he disliked, and when the people asked too many questions, he became angry and said, "Ask me (any question)." A man got up and said, "O Allah's Apostle! Who is my father?" The Prophet (ﷺ) replied, "Your father is Hudhaifa." Then another man got up and said, "O Allah's Messenger (ﷺ)! Who is my father?" The Prophet (ﷺ) said, "Your father is Salim, Maula Shaiba." When `Umar saw the signs of anger on the face of Allah's Messenger (ﷺ), he said, "We repent to Allah}}
\hadithdefcmd{bukhari}{7292}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ وَرَّادٍ، كَاتِبِ الْمُغِيرَةِ قَالَ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ اكْتُبْ إِلَىَّ مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَكَتَبَ إِلَيْهِ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي دُبُرِ كُلِّ صَلاَةٍ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ، اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ، وَلاَ مُعْطِيَ لِمَا مَنَعْتَ، وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏‏.‏ وَكَتَبَ إِلَيْهِ إِنَّهُ كَانَ يَنْهَى عَنْ قِيلَ وَقَالَ، وَكَثْرَةِ السُّؤَالِ، وَإِضَاعَةِ الْمَالِ، وَكَانَ يَنْهَى عَنْ عُقُوقِ الأُمَّهَاتِ وَوَأْدِ الْبَنَاتِ وَمَنْعٍ وَهَاتِ‏.‏\hadithno{7292}\hadithtrans{Narrated Warrad:(The clerk of Al-Mughira) Muawiya wrote to Al-Mughira 'Write to me what you have heard from Allah's Messenger (ﷺ).' So he (Al-Mughira) wrote to him: Allah's Prophet used to say at the end of each prayer: "La ilaha illalla-h wahdahu la sharika lahu, lahul Mulku, wa lahul Hamdu wa hula ala kulli shai'in qadir. 'Allahumma la mani' a lima a'taita, wala mu'tiya lima mana'ta, wala yanfa'u dhuljadd minkal-jadd." He also wrote to him that the Prophet (ﷺ) used to forbid (1) Qil and Qal (idle useless talk or that you talk too much about others), (2) Asking too many questions (in disputed Religious matters); (3) And wasting one's wealth by extravagance; (4) and to be undutiful to one's mother (5) and to bury the daughters alive (6) and to prevent your favors (benevolence to others (i.e. not to pay the rights of others (7) And asking others for something (except when it is unavoidable)}}
\hadithdefcmd{bukhari}{7293}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كُنَّا عِنْدَ عُمَرَ فَقَالَ نُهِينَا عَنِ التَّكَلُّفِ‏.‏\hadithno{7293}\hadithtrans{Narrated Anas:We were with `Umar and he said, "We have been forbidden to undertake a difficult task beyond our capability (i.e. to exceed the religious limits e.g., to clean the inside of the eyes while doing ablution)}}
\hadithdefcmd{bukhari}{7294}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ،‏.‏ وَحَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ حِينَ زَاغَتِ الشَّمْسُ فَصَلَّى الظُّهْرَ فَلَمَّا سَلَّمَ قَامَ عَلَى الْمِنْبَرِ فَذَكَرَ السَّاعَةَ، وَذَكَرَ أَنَّ بَيْنَ يَدَيْهَا أُمُورًا عِظَامًا ثُمَّ قَالَ ‏"‏ مَنْ أَحَبَّ أَنْ يَسْأَلَ عَنْ شَىْءٍ فَلْيَسْأَلْ عَنْهُ، فَوَاللَّهِ لاَ تَسْأَلُونِي عَنْ شَىْءٍ إِلاَّ أَخْبَرْتُكُمْ بِهِ، مَا دُمْتُ فِي مَقَامِي هَذَا ‏"‏‏.‏ قَالَ أَنَسٌ فَأَكْثَرَ النَّاسُ الْبُكَاءَ، وَأَكْثَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَقُولَ ‏"‏ سَلُونِي ‏"‏‏.‏ فَقَالَ أَنَسٌ فَقَامَ إِلَيْهِ رَجُلٌ فَقَالَ أَيْنَ مَدْخَلِي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ النَّارُ ‏"‏‏.‏ فَقَامَ عَبْدُ اللَّهِ بْنُ حُذَافَةَ فَقَالَ مَنْ أَبِي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏‏.‏ قَالَ ثُمَّ أَكْثَرَ أَنْ يَقُولَ ‏"‏ سَلُونِي سَلُونِي ‏"‏‏.‏ فَبَرَكَ عُمَرُ عَلَى رُكْبَتَيْهِ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا، وَبِالإِسْلاَمِ دِينًا، وَبِمُحَمَّدٍ صلى الله عليه وسلم رَسُولاً‏.‏ قَالَ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قَالَ عُمَرُ ذَلِكَ، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ عُرِضَتْ عَلَىَّ الْجَنَّةُ وَالنَّارُ آنِفًا فِي عُرْضِ هَذَا الْحَائِطِ وَأَنَا أُصَلِّي، فَلَمْ أَرَ كَالْيَوْمِ فِي الْخَيْرِ وَالشَّرِّ ‏"‏‏.‏\hadithno{7294}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) came out after the sun had declined and offered the Zuhr prayer (in congregation). After finishing it with Taslim, he stood on the pulpit and mentioned the Hour and mentioned there would happen great events before it. Then he said, "Whoever wants to ask me any question, may do so, for by Allah, you will not ask me about anything but I will inform you of its answer as long as I am at this place of mine." On this, the Ansar wept violently, and Allah's Messenger (ﷺ) kept on saying, "Ask Me! " Then a man got up and asked, ''Where will my entrance be, O Allah's Messenger (ﷺ)?" The Prophet (ﷺ) said, "(You will go to) the Fire." Then `Abdullah bin Hudhaifa got up and asked, "Who is my father, O Allah's Messenger (ﷺ)?" The Prophet (ﷺ) replied, "Your father is Hudhaifa." The Prophet (ﷺ) then kept on saying (angrily), "Ask me! Ask me!" `Umar then knelt on his knees and said, "We have accepted Allah as our Lord and Islam as our religion and Muhammad as an Apostle." Allah's Messenger (ﷺ) became quiet when `Umar said that. Then Allah's Messenger (ﷺ) said, "By Him in Whose Hand my life is, Paradise and Hell were displayed before me across this wall while I was praying, and I never saw such good and evil as I have seen today}}
\hadithdefcmd{bukhari}{7295}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي مُوسَى بْنُ أَنَسٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ قَالَ رَجُلٌ يَا نَبِيَّ اللَّهِ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ فُلاَنٌ ‏"‏‏.‏ وَنَزَلَتْ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ‏\}‏ الآيَةَ‏.‏\hadithno{7295}\hadithtrans{Narrated Anas bin Malik:A man said, "O Allah's Prophet! Who is my father?" The Prophet (ﷺ) said, "Your father is so-and-so." And then the Divine Verse:-- 'O you who believe! Ask not questions about things}}
\hadithdefcmd{bukhari}{7296}{حَدَّثَنَا الْحَسَنُ بْنُ صَبَّاحٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا وَرْقَاءُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَنْ يَبْرَحَ النَّاسُ يَتَسَاءَلُونَ حَتَّى يَقُولُوا هَذَا اللَّهُ خَالِقُ كُلِّ شَىْءٍ فَمَنْ خَلَقَ اللَّهَ ‏"‏‏.‏\hadithno{7296}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "People will not stop asking questions till they say, 'This is Allah, the Creator of everything, then who created Allah?}}
\hadithdefcmd{bukhari}{7297}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرْثٍ بِالْمَدِينَةِ، وَهْوَ يَتَوَكَّأُ عَلَى عَسِيبٍ، فَمَرَّ بِنَفَرٍ مِنَ الْيَهُودِ فَقَالَ بَعْضُهُمْ سَلُوهُ عَنِ الرُّوحِ‏.‏ وَقَالَ بَعْضُهُمْ لاَ تَسْأَلُوهُ لاَ يُسْمِعْكُمْ مَا تَكْرَهُونَ‏.‏ فَقَامُوا إِلَيْهِ فَقَالُوا يَا أَبَا الْقَاسِمِ حَدِّثْنَا عَنِ الرُّوحِ‏.‏ فَقَامَ سَاعَةً يَنْظُرُ فَعَرَفْتُ أَنَّهُ يُوحَى إِلَيْهِ، فَتَأَخَّرْتُ عَنْهُ حَتَّى صَعِدَ الْوَحْىُ، ثُمَّ قَالَ ‏\{‏وَيَسْأَلُونَكَ عَنِ الرُّوحِ قُلِ الرُّوحُ مِنْ أَمْرِ رَبِّي‏\}‏‏.‏\hadithno{7297}\hadithtrans{Narrated Ibn Masud:I was with the Prophet (ﷺ) at one of the farms of Medina while he was leaning on a date palm leaf-stalk. He passed by a group of Jews and some of them said to the other, Ask him (the Prophet) about the spirit. Some others said, "Do not ask him, lest he should tell you what you dislike" But they went up to him and said, "O Abal Qasim! Inform us bout the spirit." The Prophet (ﷺ) stood up for a while, waiting. I realized that he was being Divinely Inspired, so I kept away from him till the inspiration was over. Then the Prophet (ﷺ) said, "(O Muhammad) they ask you regarding the spirit, Say: The spirit its knowledge is with my Lord (i.e., nobody has its knowledge except Allah)" (17.85) (This is a miracle of the Qur'an that all the scientists up till now do not know about the spirit, i.e, how life comes to a body and how it goes away at its death) (See Hadith No. 245, Vol)}}
\hadithdefcmd{bukhari}{7298}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ اتَّخَذَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا مِنْ ذَهَبٍ فَاتَّخَذَ النَّاسُ خَوَاتِيمَ مِنْ ذَهَبٍ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي اتَّخَذْتُ خَاتَمًا مِنْ ذَهَبٍ ‏"‏‏.‏ فَنَبَذَهُ وَقَالَ ‏"‏ إِنِّي لَنْ أَلْبَسَهُ أَبَدًا ‏"‏ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ‏.‏\hadithno{7298}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) wore a gold ring and then the people followed him and wore gold rings too. Then the Prophet said, "I had this golden ring made for myself. He then threw it away and said, "I shall never put it on." Thereupon the people also threw their rings away}}
\hadithdefcmd{bukhari}{7299}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُوَاصِلُوا ‏"‏‏.‏ قَالُوا إِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏"‏ إِنِّي لَسْتُ مِثْلَكُمْ، إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِي ‏"‏‏.‏ فَلَمْ يَنْتَهُوا عَنِ الْوِصَالِ ـ قَالَ ـ فَوَاصَلَ بِهِمُ النَّبِيُّ صلى الله عليه وسلم يَوْمَيْنِ أَوْ لَيْلَتَيْنِ، ثُمَّ رَأَوُا الْهِلاَلَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ تَأَخَّرَ الْهِلاَلُ لَزِدْتُكُمْ ‏"‏‏.‏ كَالْمُنَكِّلِ لَهُمْ‏.‏\hadithno{7299}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said (to his companions), "Do not fast Al-Wisal." They said, "But you fast Al-Wisail." He said, "I am not like you, for at night my Lord feeds me and makes me drink." But the people did not give up Al-Wisal, so the Prophet (ﷺ) fasted Al-Wisal with them for two days or two nights, and then they saw the crescent whereupon the Prophet (ﷺ) said, "If the crescent had delayed, I would have continued fasting (because of you)," as if he wanted to vanquish them completely (because they had refused to give up Al Wisal)}}
\hadithdefcmd{bukhari}{7300}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ التَّيْمِيُّ، حَدَّثَنِي أَبِي قَالَ، خَطَبَنَا عَلِيٌّ ـ رضى الله عنه ـ عَلَى مِنْبَرٍ مِنْ آجُرٍّ، وَعَلَيْهِ سَيْفٌ فِيهِ صَحِيفَةٌ مُعَلَّقَةٌ فَقَالَ وَاللَّهِ مَا عِنْدَنَا مِنْ كِتَابٍ يُقْرَأُ إِلاَّ كِتَابُ اللَّهِ وَمَا فِي هَذِهِ الصَّحِيفَةِ‏.‏ فَنَشَرَهَا فَإِذَا فِيهَا أَسْنَانُ الإِبِلِ وَإِذَا فِيهَا ‏"‏ الْمَدِينَةُ حَرَمٌ مِنْ عَيْرٍ إِلَى كَذَا، فَمَنْ أَحْدَثَ فِيهَا حَدَثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يَقْبَلُ اللَّهُ مِنْهُ صَرْفًا وَلاَ عَدْلاً ‏"‏‏.‏ وَإِذَا فِيهِ ‏"‏ ذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ، فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يَقْبَلُ اللَّهُ مِنْهُ صَرْفًا وَلاَ عَدْلاً ‏"‏‏.‏ وَإِذَا فِيهَا ‏"‏ مَنْ وَالَى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ صَرْفًا وَلاَ عَدْلاً ‏"‏‏.‏\hadithno{7300}\hadithtrans{Narrated Ibrahim At Taimi's father:`Ali addressed us while he was standing on a brick pulpit and carrying a sword from which was hanging a scroll He said "By Allah, we have no book to read except Allah's Book and whatever is on this scroll," And then he unrolled it, and behold, in it was written what sort of camels were to be given as blood money, and there was also written in it: 'Medina is a sanctuary form 'Air (mountain) to such and such place so whoever innovates in it an heresy or commits a sin therein, he will incur the curse of Allah, the angels, and all the people and Allah will not accept his compulsory or optional good deeds.' There was also written in it: 'The asylum (pledge of protection) granted by any Muslims is one and the same, (even a Muslim of the lowest status is to be secured and respected by all the other Muslims, and whoever betrays a Muslim in this respect (by violating the pledge) will incur the curse of Allah, the angels, and all the people, and Allah will not accept his compulsory or optional good deeds.' There was also written in it: 'Whoever (freed slave) befriends (takes as masters) other than his real masters (manumitters) without their permission will incur the curse of Allah, the angels, and all the people, and Allah will not accept his compulsory or optional good deeds. ' (See Hadith No. 94, Vol)}}
\hadithdefcmd{bukhari}{7301}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا مُسْلِمٌ، عَنْ مَسْرُوقٍ، قَالَ قَالَتْ عَائِشَةُ ـ رَضِيَ الله عنها ـ صَنَعَ النَّبِيُّ صلى الله عليه وسلم شَيْئًا تَرَخَّصَ وَتَنَزَّهَ عَنْهُ قَوْمٌ، فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَحَمِدَ اللَّهَ ثُمَّ قَالَ ‏ "‏ مَا بَالُ أَقْوَامٍ يَتَنَزَّهُونَ عَنِ الشَّىْءِ أَصْنَعُهُ، فَوَاللَّهِ إِنِّي أَعْلَمُهُمْ بِاللَّهِ، وَأَشَدُّهُمْ لَهُ خَشْيَةً ‏"‏‏.‏\hadithno{7301}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) did something as it was allowed from the religious point of view but some people refrained from it. When the Prophet (ﷺ) heard of that, he, after glorifying and praising Allah, said, "Why do some people refrain from doing something which I do? By Allah, I know Allah more than they}}
\hadithdefcmd{bukhari}{7302}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا وَكِيعٌ، عَنْ نَافِعِ بْنِ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ كَادَ الْخَيِّرَانِ أَنْ يَهْلِكَا أَبُو بَكْرٍ، وَعُمَرُ، لَمَّا قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَفْدُ بَنِي تَمِيمٍ، أَشَارَ أَحَدُهُمَا بِالأَقْرَعِ بْنِ حَابِسٍ الْحَنْظَلِيِّ أَخِي بَنِي مُجَاشِعٍ، وَأَشَارَ الآخَرُ بِغَيْرِهِ، فَقَالَ أَبُو بَكْرٍ لِعُمَرَ إِنَّمَا أَرَدْتَ خِلاَفِي‏.‏ فَقَالَ عُمَرُ مَا أَرَدْتُ خِلاَفَكَ‏.‏ فَارْتَفَعَتْ أَصْوَاتُهُمَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَنَزَلَتْ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَرْفَعُوا أَصْوَاتَكُمْ‏\}‏ إِلَى قَوْلِهِ ‏\{‏عَظِيمٌ‏\}‏‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ قَالَ ابْنُ الزُّبَيْرِ فَكَانَ عُمَرُ بَعْدُ ـ وَلَمْ يَذْكُرْ ذَلِكَ عَنْ أَبِيهِ يَعْنِي أَبَا بَكْرٍ ـ إِذَا حَدَّثَ النَّبِيَّ صلى الله عليه وسلم بِحَدِيثٍ حَدَّثَهُ كَأَخِي السِّرَارِ، لَمْ يُسْمِعْهُ حَتَّى يَسْتَفْهِمَهُ‏.‏\hadithno{7302}\hadithtrans{Narrated Ibn Abi Mulaika:Once the two righteous men, i.e., Abu Bakr and `Umar were on the verge of destruction (and that was because): When the delegate of Bani Tamim came to the Prophet, one of them (either Abu Bakr or `Umar) recommended Al-Aqra' bin H`Abis at-Tamimi Al-Hanzali, the brother of Bani Majashi (to be appointed as their chief), while the other recommended somebody else. Abu Bakr said to `Umar, "You intended only to oppose me." `Umar said, "I did not intend to oppose you!" Then their voices grew louder in front of the Prophet (ﷺ) whereupon there was revealed: 'O you who believe! Do not raise your voices above the voice of the Prophet..a great reward.' (49.2-3) Ibn Az-Zubair said, 'Thence forward when `Umar talked to the Prophet, he would talk like one who whispered a secret and would even fail to make the Prophet (ﷺ) hear him, in which case the Prophet (ﷺ) would ask him (to repeat his words)}}
\hadithdefcmd{bukhari}{7303}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي مَرَضِهِ ‏"‏ مُرُوا أَبَا بَكْرٍ يُصَلِّي بِالنَّاسِ ‏"‏‏.‏ قَالَتْ عَائِشَةُ قُلْتُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ، فَمُرْ عُمَرَ فَلْيُصَلِّ‏.‏ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏‏.‏ فَقَالَتْ عَائِشَةُ فَقُلْتُ لِحَفْصَةَ قُولِي إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ، فَمُرْ عُمَرَ فَلْيُصَلِّ بِالنَّاسِ، فَفَعَلَتْ حَفْصَةُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ، مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏‏.‏ قَالَتْ حَفْصَةُ لِعَائِشَةَ مَا كُنْتُ لأُصِيبَ مِنْكِ خَيْرًا‏.‏\hadithno{7303}\hadithtrans{Narrated `Aisha:(the mother of believers) Allah's Messenger (ﷺ) during his fatal ailment said, "Order Abu Bakr to lead the people in prayer." I said, "If Abu Bakr stood at your place (in prayers, the people will not be able to hear him because of his weeping, so order `Umar to lead the people in prayer." He again said, "Order Abu Bakr to lead the people in prayer " Then I said to Hafsa, "Will you say (to the Prophet), 'If Abu Bakr stood at your place, the people will not be able to hear him be cause of his weeping, so order `Umar to lead the people in prayer?" Hafsa did so, whereupon Allah's Messenger (ﷺ) said, "You are like the companions of Joseph (See Qur'an, 12:30-32). Order Abu Bakr to lead the people in prayer." Hafsa then said to me, "I have never received any good from you}}
\hadithdefcmd{bukhari}{7304}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ جَاءَ عُوَيْمِرٌ إِلَى عَاصِمِ بْنِ عَدِيٍّ فَقَالَ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَيَقْتُلُهُ، أَتَقْتُلُونَهُ بِهِ سَلْ لِي يَا عَاصِمُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ فَكَرِهَ النَّبِيُّ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَ، فَرَجَعَ عَاصِمٌ فَأَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَرِهَ الْمَسَائِلَ فَقَالَ عُوَيْمِرٌ وَاللَّهِ لآتِيَنَّ النَّبِيَّ صلى الله عليه وسلم، فَجَاءَ وَقَدْ أَنْزَلَ اللَّهُ تَعَالَى الْقُرْآنَ خَلْفَ عَاصِمٍ فَقَالَ لَهُ ‏"‏ قَدْ أَنْزَلَ اللَّهُ فِيكُمْ قُرْآنًا ‏"‏‏.‏ فَدَعَا بِهِمَا فَتَقَدَّمَا فَتَلاَعَنَا، ثُمَّ قَالَ عُوَيْمِرٌ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ، إِنْ أَمْسَكْتُهَا‏.‏ فَفَارَقَهَا وَلَمْ يَأْمُرْهُ النَّبِيُّ صلى الله عليه وسلم بِفِرَاقِهَا، فَجَرَتِ السُّنَّةُ فِي الْمُتَلاَعِنَيْنِ‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ انْظُرُوهَا فَإِنْ جَاءَتْ بِهِ أَحْمَرَ قَصِيرًا مِثْلَ وَحَرَةٍ فَلاَ أُرَاهُ إِلاَّ قَدْ كَذَبَ، وَإِنْ جَاءَتْ بِهِ أَسْحَمَ أَعْيَنَ ذَا أَلْيَتَيْنِ فَلاَ أَحْسِبُ إِلاَّ قَدْ صَدَقَ عَلَيْهَا ‏"‏‏.‏ فَجَاءَتْ بِهِ عَلَى الأَمْرِ الْمَكْرُوهِ‏.‏\hadithno{7304}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:'Uwaimir Al-`Ajlani came to `Asim bin `Adi and said, "If a man found another man with his wife and killed him, would you sentence the husband to death (in Qisas,) i.e., equality in punishment)? O `Asim! Please ask Allah's Messenger (ﷺ) about this matter on my behalf." `Asim asked the Prophet (ﷺ) but the Prophet disliked the question and disapproved of it. `Asim returned and informed 'Uwaimir that the Prophet disliked that type of question. 'Uwaimir said, "By Allah, I will go (personally) to the Prophet." 'Uwaimir came to the Prophet (ﷺ) when Allah had already revealed Qur'anic Verses (in that respect), after `Asim had left (the Prophet (ﷺ) ). So the Prophet (ﷺ) said to 'Uwaimir, "Allah has revealed Qur'anic Verses regarding you and your wife." The Prophet (ﷺ) then called for them, and they came and carried out the order of Lian. Then 'Uwaimir said, "O Allah's Messenger (ﷺ)! Now if I kept her with me, I would be accused of telling a lie." So 'Uwaimir divorced her although the Prophet (ﷺ) did not order him to do so. Later on this practice of divorcing became the tradition of couples involved in a case of Li'an. The Prophet (ﷺ) said (to the people). "Wait for her! If she delivers a red short (small) child like a Wahra (a short red animal). then I will be of the opinion that he ('Uwaimir) has told a lie but if she delivered a black big-eyed one with big buttocks, then I will be of the opinion that he has told the truth about her." 'Ultimately she gave birth to a child that proved the accusation. (See Hadith No. 269, Vol)}}
\hadithdefcmd{bukhari}{7305}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَالِكُ بْنُ أَوْسٍ النَّصْرِيُّ، وَكَانَ، مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ ذَكَرَ لِي ذِكْرًا مِنْ ذَلِكَ فَدَخَلْتُ عَلَى مَالِكٍ فَسَأَلْتُهُ فَقَالَ انْطَلَقْتُ حَتَّى أَدْخُلَ عَلَى عُمَرَ أَتَاهُ حَاجِبُهُ يَرْفَا فَقَالَ هَلْ لَكَ فِي عُثْمَانَ وَعَبْدِ الرَّحْمَنِ وَالزُّبَيْرِ وَسَعْدٍ يَسْتَأْذِنُونَ‏.‏ قَالَ نَعَمْ‏.‏ فَدَخَلُوا فَسَلَّمُوا وَجَلَسُوا‏.‏ فَقَالَ هَلْ لَكَ فِي عَلِيٍّ وَعَبَّاسٍ‏.‏ فَأَذِنَ لَهُمَا‏.‏ قَالَ الْعَبَّاسُ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنِي وَبَيْنَ الظَّالِمِ‏.‏ اسْتَبَّا‏.‏ فَقَالَ الرَّهْطُ عُثْمَانُ وَأَصْحَابُهُ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنَهُمَا وَأَرِحْ أَحَدَهُمَا مِنَ الآخَرِ‏.‏ فَقَالَ اتَّئِدُوا أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ، هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏‏.‏ يُرِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم نَفْسَهُ‏.‏ قَالَ الرَّهْطُ قَدْ قَالَ ذَلِكَ‏.‏ فَأَقْبَلَ عُمَرُ عَلَى عَلِيٍّ وَعَبَّاسٍ فَقَالَ أَنْشُدُكُمَا بِاللَّهِ هَلْ تَعْلَمَانِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ذَلِكَ‏.‏ قَالاَ نَعَمْ‏.‏ قَالَ عُمَرُ فَإِنِّي مُحَدِّثُكُمْ عَنْ هَذَا الأَمْرِ، إِنَّ اللَّهَ كَانَ خَصَّ رَسُولَهُ صلى الله عليه وسلم فِي هَذَا الْمَالِ بِشَىْءٍ لَمْ يُعْطِهِ أَحَدًا غَيْرَهُ، فَإِنَّ اللَّهَ يَقُولُ ‏\{‏مَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ‏\}‏ الآيَةَ، فَكَانَتْ هَذِهِ خَالِصَةً لِرَسُولِ اللَّهِ صلى الله عليه وسلم، ثُمَّ وَاللَّهِ مَا احْتَازَهَا دُونَكُمْ وَلاَ اسْتَأْثَرَ بِهَا عَلَيْكُمْ، وَقَدْ أَعْطَاكُمُوهَا وَبَثَّهَا فِيكُمْ، حَتَّى بَقِيَ مِنْهَا هَذَا الْمَالُ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يُنْفِقُ عَلَى أَهْلِهِ نَفَقَةَ سَنَتِهِمْ مِنْ هَذَا الْمَالِ، ثُمَّ يَأْخُذُ مَا بَقِيَ فَيَجْعَلُهُ مَجْعَلَ مَالِ اللَّهِ، فَعَمِلَ النَّبِيُّ صلى الله عليه وسلم بِذَلِكَ حَيَاتَهُ، أَنْشُدُكُمْ بِاللَّهِ هَلْ تَعْلَمُونَ ذَلِكَ فَقَالُوا نَعَمْ‏.‏ ثُمَّ قَالَ لِعَلِيٍّ وَعَبَّاسٍ أَنْشُدُكُمَا اللَّهَ هَلْ تَعْلَمَانِ ذَلِكَ قَالاَ نَعَمْ‏.‏ ثُمَّ تَوَفَّى اللَّهُ نَبِيَّهُ صلى الله عليه وسلم فَقَالَ أَبُو بَكْرٍ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَقَبَضَهَا أَبُو بَكْرٍ فَعَمِلَ فِيهَا بِمَا عَمِلَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم، وَأَنْتُمَا حِينَئِذٍ ـ وَأَقْبَلَ عَلَى عَلِيٍّ وَعَبَّاسٍ ـ تَزْعُمَانِ أَنَّ أَبَا بَكْرٍ فِيهَا كَذَا، وَاللَّهُ يَعْلَمُ أَنَّهُ فِيهَا صَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ، ثُمَّ تَوَفَّى اللَّهُ أَبَا بَكْرٍ فَقُلْتُ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ‏.‏ فَقَبَضْتُهَا سَنَتَيْنِ أَعْمَلُ فِيهَا بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ، ثُمَّ جِئْتُمَانِي وَكَلِمَتُكُمَا عَلَى كَلِمَةٍ وَاحِدَةٍ وَأَمْرُكُمَا جَمِيعٌ، جِئْتَنِي تَسْأَلُنِي نَصِيبَكَ مِنِ ابْنِ أَخِيكَ، وَأَتَانِي هَذَا يَسْأَلُنِي نَصِيبَ امْرَأَتِهِ مِنْ أَبِيهَا فَقُلْتُ إِنْ شِئْتُمَا دَفَعْتُهَا إِلَيْكُمَا، عَلَى أَنَّ عَلَيْكُمَا عَهْدَ اللَّهِ وَمِيثَاقَهُ تَعْمَلاَنِ فِيهَا بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِمَا عَمِلَ فِيهَا أَبُو بَكْرٍ وَبِمَا عَمِلْتُ فِيهَا مُنْذُ وَلِيتُهَا، وَإِلاَّ فَلاَ تُكَلِّمَانِي فِيهَا‏.‏ فَقُلْتُمَا ادْفَعْهَا إِلَيْنَا بِذَلِكَ‏.‏ فَدَفَعْتُهَا إِلَيْكُمَا بِذَلِكَ، أَنْشُدُكُمْ بِاللَّهِ هَلْ دَفَعْتُهَا إِلَيْهِمَا بِذَلِكَ قَالَ الرَّهْطُ نَعَمْ‏.‏ فَأَقْبَلَ عَلَى عَلِيٍّ وَعَبَّاسٍ فَقَالَ أَنْشُدُكُمَا بِاللَّهِ هَلْ دَفَعْتُهَا إِلَيْكُمَا بِذَلِكَ‏.‏ قَالاَ نَعَمْ‏.‏ قَالَ أَفَتَلْتَمِسَانِ مِنِّي قَضَاءً غَيْرَ ذَلِكَ فَوَالَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ لاَ أَقْضِي فِيهَا قَضَاءً غَيْرَ ذَلِكَ حَتَّى تَقُومَ السَّاعَةُ، فَإِنْ عَجَزْتُمَا عَنْهَا فَادْفَعَاهَا إِلَىَّ، فَأَنَا أَكْفِيكُمَاهَا‏.‏\hadithno{7305}\hadithtrans{Narrated Malik bin Aus An-Nasri:I proceeded till I entered upon `Umar (and while I was sitting there), his gate-keeper Yarfa came to him and said, " `Uthman, `Abdur-Rahman, Az-Zubair and Sa`d ask your permission to come in." `Umar allowed them. So they entered, greeted, and sat down. (After a while the gatekeeper came) and said, "Shall I admit `Ali and `Abbas?'' `Umar allowed them to enter. Al-`Abbas said "O Chief of the believers! Judge between me and the oppressor (`Ali)." Then there was a dispute (regarding the property of Bani Nadir) between them (`Abbas and `Ali). `Uthman and his companions said, "O Chief of the Believers! Judge between them and relieve one from the other." `Umar said, "Be patient! beseech you by Allah, with Whose permission the Heaven and the Earth Exist! Do you know that Allah's Messenger (ﷺ) said, 'Our property is not to be inherited, and whatever we leave is to be given in charity,' and by this Allah's Messenger (ﷺ) meant himself?" On that the group said, "He verily said so." `Umar then faced `Ali and `Abbas and said, "I beseech you both by Allah, do you both know that Allah's Messenger (ﷺ) said so?" They both replied, "Yes". `Umar then said, "Now I am talking to you about this matter (in detail) . Allah favored Allah's Messenger (ﷺ) with some of this wealth which He did not give to anybody else, as Allah said: 'What Allah bestowed as Fai (Booty on His Apostle for which you made no expedition... ' (59.6) So that property was totally meant for Allah's Messenger (ﷺ), yet he did not collect it and ignore you, nor did he withhold it with your exclusion, but he gave it to you and distributed it among you till this much of it was left behind, and the Prophet, used to spend of this as the yearly expenditures of his family and then take what remained of it and spent it as he did with (other) Allah's wealth. The Prophet (ﷺ) did so during all his lifetime, and I beseech you by Allah, do you know that?" They replied, "Yes." `Umar then addressed `Ali and `Abbas, saying, "I beseech you both by Allah, do you know that?" Both of them replied, "Yes." `Umar added, "Then Allah took His Apostle unto Him. Abu Bakr then said 'I am the successor of Allah's Messenger (ﷺ)' and took over all the Prophet's property and disposed of it in the same way as Allah's Messenger (ﷺ) used to do, and you were present then." Then he turned to `Ali and `Abbas and said, "You both claim that Abu Bakr did so-and-so in managing the property, but Allah knows that Abu Bakr was honest, righteous, intelligent, and a follower of what is right in managing it. Then Allah took Abu Bakr unto Him, 'I said: I am the successor of Allah's Messenger (ﷺ) and Abu Bakr.' So I took over the property for two years and managed it in the same way as Allah's Messenger (ﷺ), and Abu Bakr used to do. Then you both (`Ali and `Abbas) came to me and asked for the same thing! (O `Abbas! You came to me to ask me for your share from nephew's property; and this (`Ali) came to me asking for his wives share from her father's property, and I said to you both, 'If you wish, I will place it in your custody on condition that you both will manage it in the same way as Allah's Messenger (ﷺ) and Abu Bakr did and as I have been doing since I took charge of managing it; otherwise, do not speak to me anymore about it.' Then you both said, 'Give it to us on that (condition).' So I gave it to you on that condition. Now I beseech you by Allah, did I not give it to them on that condition?" The group (whom he had been addressing) replied, "Yes." `Umar then addressed `Abbas and `Ali saying, "I beseech you both by Allah, didn't I give you all that property on that condition?" They said, "Yes." `Umar then said, "Are you now seeking a verdict from me other than that? By Him with Whose Permission the Heaven and the Earth exists I will not give any verdict other than that till the Hour is established; and if you both are unable to manage this property, then you can hand it back to me, and I will be sufficient for it on your behalf." (See, Hadith No. 326, Vol)}}
\hadithdefcmd{bukhari}{7306}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عَاصِمٌ، قَالَ قُلْتُ لأَنَسٍ أَحَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ‏.‏ قَالَ نَعَمْ مَا بَيْنَ كَذَا إِلَى كَذَا، لاَ يُقْطَعُ شَجَرُهَا، مَنْ أَحْدَثَ فِيهَا حَدَثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ‏.‏ قَالَ عَاصِمٌ فَأَخْبَرَنِي مُوسَى بْنُ أَنَسٍ أَنَّهُ قَالَ أَوْ آوَى مُحْدِثًا‏.‏\hadithno{7306}\hadithtrans{Narrated `Asim:I said to Anas, "Did Allah's Messenger (ﷺ) make Medina a sanctuary?" He replied, "Yes, (Medina is a sanctuary from such-and-such place to such-and-such place. It is forbidden to cut its trees, and whoever innovates an heresy in it or commits a sin therein, will incur the curse of Allah, the angels, and all the people." Then Musa bin Anas told me that Anas added, "..... or gives refuge to such an heretic or a sinner)}}
\hadithdefcmd{bukhari}{7307}{حَدَّثَنَا سَعِيدُ بْنُ تَلِيدٍ، حَدَّثَنِي ابْنُ وَهْبٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، وَغَيْرُهُ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، قَالَ حَجَّ عَلَيْنَا عَبْدُ اللَّهِ بْنُ عَمْرٍو فَسَمِعْتُهُ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ لاَ يَنْزِعُ الْعِلْمَ بَعْدَ أَنْ أَعْطَاهُمُوهُ انْتِزَاعًا، وَلَكِنْ يَنْتَزِعُهُ مِنْهُمْ مَعَ قَبْضِ الْعُلَمَاءِ بِعِلْمِهِمْ، فَيَبْقَى نَاسٌ جُهَّالٌ يُسْتَفْتَوْنَ فَيُفْتُونَ بِرَأْيِهِمْ، فَيُضِلُّونَ وَيَضِلُّونَ ‏"‏‏.‏ فَحَدَّثْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ إِنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو حَجَّ بَعْدُ فَقَالَتْ يَا ابْنَ أُخْتِي انْطَلِقْ إِلَى عَبْدِ اللَّهِ فَاسْتَثْبِتْ لِي مِنْهُ الَّذِي حَدَّثْتَنِي عَنْهُ‏.‏ فَجِئْتُهُ فَسَأَلْتُهُ فَحَدَّثَنِي بِهِ كَنَحْوِ مَا حَدَّثَنِي، فَأَتَيْتُ عَائِشَةَ فَأَخْبَرْتُهَا فَعَجِبَتْ فَقَالَتْ وَاللَّهِ لَقَدْ حَفِظَ عَبْدُ اللَّهِ بْنُ عَمْرٍو‏.‏\hadithno{7307}\hadithtrans{Narrated `Abdullah bin `Amr:I heard the Prophet (ﷺ) saying, "Allah will not deprive you of knowledge after he has given it to you, but it will be taken away through the death of the religious learned men with their knowledge. Then there will remain ignorant people who, when consulted, will give verdicts according to their opinions whereby they will mislead others and go astray}}
\hadithdefcmd{bukhari}{7308}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا أَبُو حَمْزَةَ، سَمِعْتُ الأَعْمَشَ، قَالَ سَأَلْتُ أَبَا وَائِلٍ هَلْ شَهِدْتَ صِفِّينَ قَالَ نَعَمْ‏.‏ فَسَمِعْتُ سَهْلَ بْنَ حُنَيْفٍ، يَقُولُ ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ سَهْلُ بْنُ حُنَيْفٍ يَا أَيُّهَا النَّاسُ اتَّهِمُوا رَأْيَكُمْ عَلَى دِينِكُمْ، لَقَدْ رَأَيْتُنِي يَوْمَ أَبِي جَنْدَلٍ وَلَوْ أَسْتَطِيعُ أَنَّ أَرُدَّ أَمْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَرَدَدْتُهُ، وَمَا وَضَعْنَا سُيُوفَنَا عَلَى عَوَاتِقِنَا إِلَى أَمْرٍ يُفْظِعُنَا إِلاَّ أَسْهَلْنَ بِنَا إِلَى أَمْرٍ نَعْرِفُهُ غَيْرَ هَذَا الأَمْرِ‏.‏ قَالَ وَقَالَ أَبُو وَائِلٍ شَهِدْتُ صِفِّينَ وَبِئْسَتْ صِفُّونَ‏.‏\hadithno{7308}\hadithtrans{Narrated Al-A`mash:I asked Abu Wail, "Did you witness the battle of Siffin between `Ali and Muawiya?" He said, "Yes," and added, "Then I heard Sahl bin Hunaif saying, 'O people! Blame your personal opinions in your religion. No doubt, I remember myself on the day of Abi Jandal; if I had the power to refuse the order of Allah's Messenger (ﷺ), I would have refused it. We have never put our swords on our shoulders to get involved in a situation that might have been horrible for us, but those swords brought us to victory and peace, except this present situation.' " Abu Wail said, "I witnessed the battle of Siffin, and how nasty Siffin was}}
\hadithdefcmd{bukhari}{7309}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ ابْنَ الْمُنْكَدِرِ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَرِضْتُ فَجَاءَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي وَأَبُو بَكْرٍ وَهُمَا مَاشِيَانِ، فَأَتَانِي وَقَدْ أُغْمِيَ عَلَىَّ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَبَّ وَضُوءَهُ عَلَىَّ فَأَفَقْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ ـ وَرُبَّمَا قَالَ سُفْيَانُ فَقُلْتُ أَىْ رَسُولَ اللَّهِ ـ كَيْفَ أَقْضِي فِي مَالِي كَيْفَ أَصْنَعُ فِي مَالِي قَالَ فَمَا أَجَابَنِي بِشَىْءٍ حَتَّى نَزَلَتْ آيَةُ الْمِيرَاثِ‏.‏\hadithno{7309}\hadithtrans{Narrated Jabir bin `Abdullah:I fell ill, Allah's Messenger (ﷺ) and Abu Bakr came to visit me on foot. The Prophet (ﷺ) came to me while I was unconscious. Allah's Messenger (ﷺ) performed ablution and poured the Remaining water of his ablution over me whereupon I became conscious and said, 'O Allah's Messenger (ﷺ)! How should I spend my wealth? Or how should I deal with my wealth?" But the Prophet (ﷺ) did not give me any reply till the Verse of the laws of inheritance was revealed}}
\hadithdefcmd{bukhari}{7310}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، عَنْ أَبِي صَالِحٍ، ذَكْوَانَ عَنْ أَبِي سَعِيدٍ، جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ ذَهَبَ الرِّجَالُ بِحَدِيثِكَ، فَاجْعَلْ لَنَا مِنْ نَفْسِكَ، يَوْمًا نَأْتِيكَ فِيهِ تُعَلِّمُنَا مِمَّا عَلَّمَكَ اللَّهُ‏.‏ فَقَالَ ‏"‏ اجْتَمِعْنَ فِي يَوْمِ كَذَا وَكَذَا فِي مَكَانِ كَذَا وَكَذَا ‏"‏‏.‏ فَاجْتَمَعْنَ فَأَتَاهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَعَلَّمَهُنَّ مِمَّا عَلَّمَهُ اللَّهُ ثُمَّ قَالَ ‏"‏ مَا مِنْكُنَّ امْرَأَةٌ تُقَدِّمُ بَيْنَ يَدَيْهَا مِنْ وَلَدِهَا ثَلاَثَةً، إِلاَّ كَانَ لَهَا حِجَابًا مِنَ النَّارِ ‏"‏‏.‏ فَقَالَتِ امْرَأَةٌ مِنْهُنَّ يَا رَسُولَ اللَّهِ اثْنَيْنِ قَالَ فَأَعَادَتْهَا مَرَّتَيْنِ ثُمَّ قَالَ ‏"‏ وَاثْنَيْنِ وَاثْنَيْنِ وَاثْنَيْنِ ‏"‏‏.‏\hadithno{7310}\hadithtrans{Narrated Abu Sa`id:A woman came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Men (only) benefit by your teachings, so please devote to us from (some of) your time, a day on which we may come to you so that you may teach us of what Allah has taught you." Allah's Messenger (ﷺ) said, "Gather on such-and-such a day at suchand- such a place." They gathered and Allah's Messenger (ﷺ) came to them and taught them of what Allah had taught him. He then said, "No woman among you who has lost her three children (died) but that they will screen her from the Fire." A woman among them said, "O Allah's Messenger (ﷺ)! If she lost two children?" She repeated her question twice, whereupon the Prophet (ﷺ) said, "Even two, even two, even two!" (See Hadith No. 341, Vol)}}
\hadithdefcmd{bukhari}{7311}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ طَائِفَةٌ مِنْ أُمَّتِي ظَاهِرِينَ حَتَّى يَأْتِيَهُمْ أَمْرُ اللَّهِ وَهُمْ ظَاهِرُونَ ‏"‏‏.‏\hadithno{7311}\hadithtrans{Narrated Al-Mughira bin Shu`ba:The Prophet (ﷺ) said, "A group of my follower swill remain predominant (victorious) till Allah's Order (the Hour) comes upon them while they are still predominant (victorious)}}
\hadithdefcmd{bukhari}{7312}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي حُمَيْدٌ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، يَخْطُبُ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ، وَإِنَّمَا أَنَا قَاسِمٌ وَيُعْطِي اللَّهُ، وَلَنْ يَزَالَ أَمْرُ هَذِهِ الأُمَّةِ مُسْتَقِيمًا حَتَّى تَقُومَ السَّاعَةُ، أَوْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ ‏"‏‏.‏\hadithno{7312}\hadithtrans{Narrated Humaid:I heard Muawiya bin Abi Sufyan delivering a sermon. He said, "I heard the Prophet (ﷺ) saying, "If Allah wants to do a favor to somebody, He bestows on him, the gift of understanding the Qur'an and Sunna. I am but a distributor, and Allah is the Giver. The state of this nation will remain good till the Hour is established, or till Allah's Order comes}}
\hadithdefcmd{bukhari}{7313}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ لَمَّا نَزَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏\{‏قُلْ هُوَ الْقَادِرُ عَلَى أَنْ يَبْعَثَ عَلَيْكُمْ عَذَابًا مِنْ فَوْقِكُمْ‏\}‏ قَالَ ‏"‏ أَعُوذُ بِوَجْهِكَ ‏"‏‏.‏ ‏\{‏أَوْ مِنْ تَحْتِ أَرْجُلِكُمْ‏\}‏ قَالَ ‏"‏ أَعُوذُ بِوَجْهِكَ ‏"‏‏.‏ فَلَمَّا نَزَلَتْ ‏\{‏أَوْ يَلْبِسَكُمْ شِيَعًا وَيُذِيقَ بَعْضَكُمْ بَأْسَ بَعْضٍ‏\}‏ قَالَ ‏"‏ هَاتَانِ أَهْوَنُ أَوْ أَيْسَرُ ‏"‏‏.‏\hadithno{7313}\hadithtrans{Narrated Jabir bin `Abdullah:When the (following) Verse was revealed to Allah's Messenger (ﷺ): 'Say: He has power to send torment on you from above,'..(6.65) he said, "O Allah! I seek refuge with Your Face (from that punishment)." And when this was revealed: '..or from beneath your feet.' (6.65) he said, "O Allah! I seek refuge with Your Face (from that)." And when this Verse was revealed: '..or to cover you with confusion in partystrife, and make you to taste the violence of one another,'...(6.65) he said: "These two warnings are easier (than the previous ones)}}
\hadithdefcmd{bukhari}{7314}{حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ، حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَعْرَابِيًّا، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ، وَإِنِّي أَنْكَرْتُهُ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏‏.‏ قَالَ حُمْرٌ‏.‏ قَالَ ‏"‏ هَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏‏.‏ قَالَ إِنَّ فِيهَا لَوُرْقًا‏.‏ قَالَ ‏"‏ فَأَنَّى تُرَى ذَلِكَ جَاءَهَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ عِرْقٌ نَزَعَهَا‏.‏ قَالَ ‏"‏ وَلَعَلَّ هَذَا عِرْقٌ نَزَعَهُ ‏"‏‏.‏ وَلَمْ يُرَخِّصْ لَهُ فِي الاِنْتِفَاءِ مِنْهُ‏.‏\hadithno{7314}\hadithtrans{Narrated Abu Huraira:A bedouin came to Allah's Messenger (ﷺ) and said, "My wife has delivered a black boy, and I suspect that he is not my child." Allah's Messenger (ﷺ) said to him, "Have you got camels?" The bedouin said, "Yes." The Prophet said, "What color are they?" The bedouin said, "They are red." The Prophet (ﷺ) said, "Are any of them Grey?" He said, "There are Grey ones among them." The Prophet (ﷺ) said, "Whence do you think this color came to them?" The bedouin said, "O Allah's Messenger (ﷺ)! It resulted from hereditary disposition." The Prophet (ﷺ) said, "And this (i.e., your child) has inherited his color from his ancestors." The Prophet (ﷺ) did not allow him to deny his paternity of the child}}
\hadithdefcmd{bukhari}{7315}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، جَاءَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ أُمِّي نَذَرَتْ أَنْ تَحُجَّ فَمَاتَتْ قَبْلَ أَنْ تَحُجَّ أَفَأَحُجَّ عَنْهَا قَالَ ‏"‏ نَعَمْ حُجِّي عَنْهَا، أَرَأَيْتِ لَوْ كَانَ عَلَى أُمِّكِ دَيْنٌ أَكُنْتِ قَاضِيَتَهُ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ فَقَالَ ‏"‏ فَاقْضُوا الَّذِي لَهُ، فَإِنَّ اللَّهَ أَحَقُّ بِالْوَفَاءِ ‏"‏‏.‏\hadithno{7315}\hadithtrans{Narrated Ibn `Abbas:A woman came to the Prophet (ﷺ) and said, "My mother vowed to perform the Hajj but she died before performing it. Should I perform the Hajj on her behalf?" He said, "Yes! Perform the Hajj on her behalf. See, if your mother had been in debt, would you have paid her debt?" She said, "Yes." He said, "So you should pay what is for Him as Allah has more right that one should fulfill one's obligations to Him}}
\hadithdefcmd{bukhari}{7316}{حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حُمَيْدٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ مَالاً فَسُلِّطَ عَلَى هَلَكَتِهِ فِي الْحَقِّ، وَآخَرُ آتَاهُ اللَّهُ حِكْمَةً فَهْوَ يَقْضِي بِهَا وَيُعَلِّمُهَا ‏"‏‏.‏\hadithno{7316}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "Do not wish to be like anybody except in two cases: The case of a man whom Allah has given wealth and he spends it in the right way, and that of a man whom Allah has given religious wisdom (i.e., Qur'an and Sunna) and he gives his verdicts according to it and teaches it." (to others i.e., religious knowledge of Qur'an and Sunna (Prophet's Traditions)}}
\hadithdefcmd{bukhari}{7318}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ سَأَلَ عُمَرُ بْنُ الْخَطَّابِ عَنْ إِمْلاَصِ الْمَرْأَةِ ـ هِيَ الَّتِي يُضْرَبُ بَطْنُهَا فَتُلْقِي جَنِينًا ـ فَقَالَ أَيُّكُمْ سَمِعَ مِنَ النَّبِيِّ صلى الله عليه وسلم فِيهِ شَيْئًا فَقُلْتُ أَنَا‏.‏ فَقَالَ مَا هُوَ قُلْتُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ فِيهِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏‏.‏ فَقَالَ لاَ تَبْرَحْ حَتَّى تَجِيئَنِي بِالْمَخْرَجِ فِيمَا قُلْتَ‏.فَخَرَجْتُ فَوَجَدْتُ مُحَمَّدَ بْنَ مَسْلَمَةَ فَجِئْتُ بِهِ، فَشَهِدَ مَعِي أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ فِيهِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏‏.‏ تَابَعَهُ ابْنُ أَبِي الزِّنَادِ عَنْ أَبِيهِ عَنْ عُرْوَةَ عَنِ الْمُغِيرَةِ‏.‏\hadithno{7318}\hadithtrans{Narrated Al-Mughira bin Shu`ba:`Umar bin Al-Khattab asked (the people) about the Imlas of a woman, i.e., a woman who has an abortion because of having been beaten on her `Abdomen, saying, "Who among you has heard anything about it from the Prophet?" I said, "I did.'' He said, "What is that?" I said, "I heard the Prophet saying, "Its Diya (blood money) is either a male or a female slave.' " `Umar said, "Do not leave till you present witness in support of your statement." So I went out, and found Muhammad bin Maslama. I brought him, and he bore witness with me that he had heard the Prophet (ﷺ) saying, "Its Diya (blood money) is either a male slave or a female slave}}
\hadithdefcmd{bukhari}{7319}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَأْخُذَ أُمَّتِي بِأَخْذِ الْقُرُونِ قَبْلَهَا، شِبْرًا بِشِبْرٍ وَذِرَاعًا بِذِرَاعٍ ‏"‏‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ كَفَارِسَ وَالرُّومِ‏.‏ فَقَالَ ‏"‏ وَمَنِ النَّاسُ إِلاَّ أُولَئِكَ ‏"‏‏.‏\hadithno{7319}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till my followers copy the deeds of the previous nations and follow them very closely, span by span, and cubit by cubit (i.e., inch by inch)." It was said, "O Allah's Messenger (ﷺ)! Do you mean by those (nations) the Persians and the Byzantines?" The Prophet said, "Who can it be other than they?}}
\hadithdefcmd{bukhari}{7320}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا أَبُو عُمَرَ الصَّنْعَانِيُّ ـ مِنَ الْيَمَنِ ـ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَتَتْبَعُنَّ سَنَنَ مَنْ كَانَ قَبْلَكُمْ شِبْرًا شِبْرًا وَذِرَاعًا بِذِرَاعٍ، حَتَّى لَوْ دَخَلُوا جُحْرَ ضَبٍّ تَبِعْتُمُوهُمْ ‏"‏‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ الْيَهُودُ وَالنَّصَارَى قَالَ ‏"‏ فَمَنْ ‏"‏‏.‏\hadithno{7320}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "You will follow the ways of those nations who were before you, span by span and cubit by cubit (i.e., inch by inch) so much so that even if they entered a hole of a mastigure, you would follow them." We said, "O Allah's Messenger (ﷺ)! (Do you mean) the Jews and the Christians?" He said, "Whom else?}}
\hadithdefcmd{bukhari}{7321}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنْ نَفْسٍ تُقْتَلُ ظُلْمًا إِلاَّ كَانَ عَلَى ابْنِ آدَمَ الأَوَّلِ كِفْلٌ مِنْهَا ـ وَرُبَّمَا قَالَ سُفْيَانُ مِنْ دَمِهَا ـ لأَنَّهُ أَوَّلُ مَنْ سَنَّ الْقَتْلَ أَوَّلاً ‏"‏‏.‏\hadithno{7321}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "None is killed unjustly, but the first son of Adam will have a part of its burden." Sufyan said, "..a part of its blood because he was the first to establish the tradition of murdering}}
\hadithdefcmd{bukhari}{7322}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ السَّلَمِيِّ، أَنَّ أَعْرَابِيًّا، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ، فَأَصَابَ الأَعْرَابِيَّ وَعْكٌ بِالْمَدِينَةِ، فَجَاءَ الأَعْرَابِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَقِلْنِي بَيْعَتِي‏.‏ فَأَبَى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي‏.‏ فَأَبَى ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي‏.‏ فَأَبَى فَخَرَجَ الأَعْرَابِيُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْمَدِينَةُ كَالْكِيرِ، تَنْفِي خَبَثَهَا، وَيَنْصَعُ طِيبُهَا ‏"‏‏.‏\hadithno{7322}\hadithtrans{Narrated Jabir bin 'Abdullah As-Salami: A bedouin gave the Pledge of allegiance for embracing Islam to Allah's Messenger (ﷺ), and then he got an attack of fever in Medina and came to Allah's Messenger (ﷺ): and said, "O Allah's Messenger (ﷺ)! Cancel my pledge." Allah's Messenger (ﷺ) refused to do so. The bedouin came to him again and said, "Cancel my pledge," but he refused again, and then again, the bedouin came to him and said, "Cancel my pledge," and Allah's Messenger (ﷺ) refused. The bedouin finally went away, and Allah's Messenger (ﷺ) said, "Medina is like a pair of bellows (furnace), it expels its impurities while it brightens and clears its good}}
\hadithdefcmd{bukhari}{7323}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كُنْتُ أُقْرِئُ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، فَلَمَّا كَانَ آخِرَ حَجَّةٍ حَجَّهَا عُمَرُ فَقَالَ عَبْدُ الرَّحْمَنِ بِمِنًى، لَوْ شَهِدْتَ أَمِيرَ الْمُؤْمِنِينَ أَتَاهُ رَجُلٌ قَالَ إِنَّ فُلاَنًا يَقُولُ لَوْ مَاتَ أَمِيرُ الْمُؤْمِنِينَ لَبَايَعْنَا فُلاَنًا‏.‏ فَقَالَ عُمَرُ لأَقُومَنَّ الْعَشِيَّةَ فَأُحَذِّرَ هَؤُلاَءِ الرَّهْطَ الَّذِينَ يُرِيدُونَ أَنْ يَغْصِبُوهُمْ‏.‏ قُلْتُ لاَ تَفْعَلْ فَإِنَّ الْمَوْسِمَ يَجْمَعُ رَعَاعَ النَّاسِ يَغْلِبُونَ عَلَى مَجْلِسِكَ، فَأَخَافُ أَنْ لاَ يُنْزِلُوهَا عَلَى وَجْهِهَا فَيُطِيرُ بِهَا كُلُّ مُطِيرٍ، فَأَمْهِلْ حَتَّى تَقْدَمَ الْمَدِينَةَ دَارَ الْهِجْرَةِ وَدَارَ السُّنَّةِ، فَتَخْلُصُ بِأَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمُهَاجِرِينَ وَالأَنْصَارِ فَيَحْفَظُوا مَقَالَتَكَ، وَيُنَزِّلُوهَا عَلَى وَجْهِهَا‏.‏ فَقَالَ وَاللَّهِ لأَقُومَنَّ بِهِ فِي أَوَّلِ مَقَامٍ أَقُومُهُ بِالْمَدِينَةِ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقَدِمْنَا الْمَدِينَةَ فَقَالَ إِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ وَأَنْزَلَ عَلَيْهِ الْكِتَابَ، فَكَانَ فِيمَا أُنْزِلَ آيَةُ الرَّجْمِ‏.‏\hadithno{7323}\hadithtrans{Narrated Ibn 'Abbas: I used to teach Qur'an to 'Abdur-Rahman bin Auf. When Umar performed his last Hajj, 'Abdur-Rahman said (to me) at Mina, "Would that you had seen Chief of the believers today! A man came to him and said, "So-and-so has said, "If Chief of the Believers died, we will give the oath of allegiance to such-and-such person,' 'Umar said, 'I will get up tonight and warn those who want to usurp the people's rights.' I said, 'Do not do so, for the season (of Hajj) gathers the riffraff mob who will form the majority of your audience, and I am afraid that they will not understand (the meaning of) your saying properly and may spread (an incorrect statement) everywhere. You should wait till we reach Medina, the place of migration and the place of the Sunna (the Prophet's Traditions). There you will meet the companions of Allah's Messenger (ﷺ) from the Muhajirin and the Ansar who will understand your statement and place it in its proper position' 'Umar said, 'By Allah, I shall do so the first time I stand (to address the people) in Medina.' When we reached Medina, 'Umar (in a Friday Khutba-sermon) said, "No doubt, Allah sent Muhammad with the Truth and revealed to him the Book (Quran), and among what was revealed, was the Verse of Ar-Rajm (stoning adulterers to death).'" (See Hadith No. 817,Vol)}}
\hadithdefcmd{bukhari}{7324}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ كُنَّا عِنْدَ أَبِي هُرَيْرَةَ وَعَلَيْهِ ثَوْبَانِ مُمَشَّقَانِ مِنْ كَتَّانٍ فَتَمَخَّطَ فَقَالَ بَخْ بَخْ أَبُو هُرَيْرَةَ يَتَمَخَّطُ فِي الْكَتَّانِ، لَقَدْ رَأَيْتُنِي وَإِنِّي لأَخِرُّ فِيمَا بَيْنَ مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى حُجْرَةِ عَائِشَةَ مَغْشِيًّا عَلَىَّ، فَيَجِيءُ الْجَائِي فَيَضَعُ رِجْلَهُ عَلَى عُنُقِي، وَيُرَى أَنِّي مَجْنُونٌ، وَمَا بِي مِنْ جُنُونٍ، مَا بِي إِلاَّ الْجُوعُ‏.‏\hadithno{7324}\hadithtrans{Narrated Muhammad:We were with Abu Huraira while he was wearing two linen garments dyed with red clay. He cleaned his nose with his garment, saying, "Bravo! Bravo! Abu Huraira is cleaning his nose with linen! There came a time when I would fall senseless between the pulpit of Allah's Messenger (ﷺ) and `Aisha's dwelling whereupon a passerby would come and put his foot on my neck, considering me a mad man, but in fact, I had no madness, I suffered nothing but hunger}}
\hadithdefcmd{bukhari}{7325}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، قَالَ سُئِلَ ابْنُ عَبَّاسٍ أَشَهِدْتَ الْعِيدَ مَعَ النَّبِيِّ صلى الله عليه وسلم قَالَ نَعَمْ وَلَوْلاَ مَنْزِلَتِي مِنْهُ مَا شَهِدْتُهُ مِنَ الصِّغَرِ، فَأَتَى الْعَلَمَ الَّذِي عِنْدَ دَارِ كَثِيرِ بْنِ الصَّلْتِ فَصَلَّى ثُمَّ خَطَبَ، وَلَمْ يَذْكُرْ أَذَانًا وَلاَ إِقَامَةً، ثُمَّ أَمَرَ بِالصَّدَقَةِ فَجَعَلَ النِّسَاءُ يُشِرْنَ إِلَى آذَانِهِنَّ وَحُلُوقِهِنَّ، فَأَمَرَ بِلاَلاً فَأَتَاهُنَّ، ثُمَّ رَجَعَ إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7325}\hadithtrans{Narrated `Abdur-Rahman bin `Abis:Ibn `Abbas was asked, "Did you offer the Id prayer with the Prophet?" He said, "Yes, had it not been for my close relation to the Prophet, I would not have performed it (with him) because of my being too young The Prophet (ﷺ) came to the mark which is near the home of Kathir bin As-Salt and offered the Id prayer and then delivered the sermon. I do not remember if any Adhan or Iqama were pronounced for the prayer. Then the Prophet (ﷺ) ordered (the women) to give alms, and they started stretching out their hands towards their ears and throats (giving their ornaments in charity), and the Prophet (ﷺ) ordered Bilal to go to them (to collect the alms), and then Bilal returned to the Prophet}}
\hadithdefcmd{bukhari}{7326}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْتِي قُبَاءً مَاشِيًا وَرَاكِبًا‏.‏\hadithno{7326}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to go to the Quba' mosque, sometimes walking, sometimes riding}}
\hadithdefcmd{bukhari}{7328}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ادْفِنِّي مَعَ صَوَاحِبِي وَلاَ تَدْفِنِّي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْبَيْتِ، فَإِنِّي أَكْرَهُ أَنْ أُزَكَّى‏.‏ وَعَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنَّ عُمَرَ، أَرْسَلَ إِلَى عَائِشَةَ ائْذَنِي لِي أَنْ أُدْفَنَ مَعَ صَاحِبَىَّ فَقَالَتْ إِي وَاللَّهِ‏.‏ قَالَ وَكَانَ الرَّجُلُ إِذَا أَرْسَلَ إِلَيْهَا مِنَ الصَّحَابَةِ قَالَتْ لاَ وَاللَّهِ لاَ أُوثِرُهُمْ بِأَحَدٍ أَبَدًا‏.‏\hadithno{7328}\hadithtrans{Narrated Hisham's father:`Aisha said to `Abdullah bin Az-Zubair, "Bury me with my female companions (i.e. the wives of the Prophet) and do not bury me with the Prophet (ﷺ) in the house, for I do not like to be regarded as sanctified (just for being buried there).'' Narrated Hisham's father: `Umar sent a message to `Aisha, saying, "Will you allow me to be buried with my two companions (the Prophet (ﷺ) and Abu Bakr) ?" She said, "Yes, by Allah." though it was her habit that if a man from among the companions (of the Prophet (ﷺ) ) sent her a message asking her to allow him to be buried there, she would say, "No, by Allah, I will never give permission to anyone to be buried with them}}
\hadithdefcmd{bukhari}{7329}{حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ فَيَأْتِي الْعَوَالِيَ وَالشَّمْسُ مُرْتَفِعَةٌ‏.‏ وَزَادَ اللَّيْثُ عَنْ يُونُسَ، وَبُعْدُ الْعَوَالِي أَرْبَعَةُ أَمْيَالٍ أَوْ ثَلاَثَةٌ‏.‏\hadithno{7329}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to perform the `Asr prayer and then one could reach the `Awali (a place in the outskirts of Medina) while the sun was still quite high. Narrated Yunus: The distance of the `Awali (from Medina) was four or three miles}}
\hadithdefcmd{bukhari}{7330}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ، عَنِ الْجُعَيْدِ، سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يَقُولُ كَانَ الصَّاعُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم مُدًّا وَثُلُثًا بِمُدِّكُمُ الْيَوْمَ، وَقَدْ زِيدَ فِيهِ‏.‏ سَمِعَ الْقَاسِمُ بْنُ مَالِكٍ الْجُعَيْدَ\hadithno{7330}\hadithtrans{Narrated As-Sa'ib bin Yazid:The Sa' (a kind of measure) during the lifetime of the Prophet (ﷺ) used to be equal to the one Mudd (another kind of measure) and one third of a Mudd which we use today, but the Sa' of today has become large}}
\hadithdefcmd{bukhari}{7331}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِي مِكْيَالِهِمْ، وَبَارِكْ لَهُمْ فِي صَاعِهِمْ وَمُدِّهِمْ ‏"‏ يَعْنِي أَهْلَ الْمَدِينَةِ‏.‏\hadithno{7331}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "O Allah! Bestow Your Blessings on their measures, and bestow Your Blessings on their Sa' and Mudd." He meant those of the people of Medina}}
\hadithdefcmd{bukhari}{7332}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ الْيَهُودَ، جَاءُوا إِلَى النَّبِيِّ صلى الله عليه وسلم بِرَجُلٍ وَامْرَأَةٍ زَنَيَا، فَأَمَرَ بِهِمَا فَرُجِمَا قَرِيبًا مِنْ حَيْثُ تُوضَعُ الْجَنَائِزُ عِنْدَ الْمَسْجِدِ‏.‏\hadithno{7332}\hadithtrans{Narrated Ibn `Umar:The Jews brought a man and a woman who had committed illegal sexual intercourse, to the Prophet (ﷺ) and the Prophet (ﷺ) ordered them to be stoned to death, and they were stoned to death near the mosque where the biers used to be placed}}
\hadithdefcmd{bukhari}{7333}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَلَعَ لَهُ أُحُدٌ فَقَالَ ‏ "‏ هَذَا جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ، اللَّهُمَّ إِنَّ إِبْرَاهِيمَ حَرَّمَ مَكَّةَ، وَإِنِّي أُحَرِّمُ مَا بَيْنَ لاَبَتَيْهَا ‏"‏‏.‏ تَابَعَهُ سَهْلٌ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي أُحُدٍ‏.‏\hadithno{7333}\hadithtrans{Narrated Anas bin Malik:The Mountain of Uhud came in sight of Allah's Messenger (ﷺ) who then said, "This is a mountain that loves us and is loved by us. O Allah! Abraham made Mecca a sanctuary and I make the area between its (Medina's) two mountains a sanctuary}}
\hadithdefcmd{bukhari}{7334}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ، أَنَّهُ كَانَ بَيْنَ جِدَارِ الْمَسْجِدِ مِمَّا يَلِي الْقِبْلَةَ وَبَيْنَ الْمِنْبَرِ مَمَرُّ الشَّاةِ‏.‏\hadithno{7334}\hadithtrans{Narrated Sahl:The distance between the pulpit and the wall of the mosque on the side of the Qibla was just sufficient for a sheep to pass through}}
\hadithdefcmd{bukhari}{7335}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مَالِكٌ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ، وَمِنْبَرِي عَلَى حَوْضِي ‏"‏‏.‏\hadithno{7335}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Between my house and my pulpit there is a garden from one of the gardens of Paradise, and my pulpit is over my Lake-Tank. (Kauthar);}}
\hadithdefcmd{bukhari}{7336}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ سَابَقَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ الْخَيْلِ، فَأُرْسِلَتِ الَّتِي ضُمِّرَتْ مِنْهَا وَأَمَدُهَا إِلَى الْحَفْيَاءِ إِلَى ثَنِيَّةِ الْوَدَاعِ، وَالَّتِي لَمْ تُضَمَّرْ أَمَدُهَا ثَنِيَّةُ الْوَدَاعِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ، وَأَنَّ عَبْدَ اللَّهِ كَانَ فِيمَنْ سَابَقَ‏.‏ حَدَّثَنَا قُتَيْبَةُ عَنْ لَيْثٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ‏.‏\hadithno{7336}\hadithtrans{Narrated Nafi`:`Abdullah said, "The Prophet (ﷺ) arranged for a horse race, and the prepared horses were given less food for a few days before the race to win the race, and were allowed to run from Al-Hafya to Thaniyat-al- Wada`, and the unprepared horses were allowed to run between Thaniyat-al-Wada` and the mosque of Bani Zuraiq," `Abdullah was one of those who participated in the race}}
\hadithdefcmd{bukhari}{7337}{حَدَّثَنَا قُتَيْبَةُ عَنْ لَيْثٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ‏‏ ح. وَحَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عِيسَى، وَابْنُ، إِدْرِيسَ وَابْنُ أَبِي غَنِيَّةَ عَنْ أَبِي حَيَّانَ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ عُمَرَ، عَلَى مِنْبَرِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7337}\hadithtrans{Narrated Ibn `Umar:I heard `Umar (delivering a sermon) on the pulpit of the Prophet}}
\hadithdefcmd{bukhari}{7338}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ، سَمِعَ عُثْمَانَ بْنَ عَفَّانَ، خَطَبَنَا عَلَى مِنْبَرِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7338}\hadithtrans{Narrated As-Sa'ib bin Yazid:That he heard `Uthman bin `Affan delivering a sermon on the pulpit of the Prophet}}
\hadithdefcmd{bukhari}{7339}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، أَنَّ هِشَامَ بْنَ عُرْوَةَ، حَدَّثَهُ عَنْ أَبِيهِ، أَنَّ عَائِشَةَ، قَالَتْ كَانَ يُوضَعُ لِي وَلِرَسُولِ اللَّهِ صلى الله عليه وسلم هَذَا الْمِرْكَنُ فَنَشْرَعُ فِيهِ جَمِيعًا‏.‏\hadithno{7339}\hadithtrans{Narrated `Aisha:This big copper vessel used to be put for me and Allah's Messenger (ﷺ) and we would take water from it together (on taking a bath)}}
\hadithdefcmd{bukhari}{7341}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَنَسٍ، قَالَ حَالَفَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ الأَنْصَارِ وَقُرَيْشٍ فِي دَارِي الَّتِي بِالْمَدِينَةِ‏.‏ وَقَنَتَ شَهْرًا يَدْعُو عَلَى أَحْيَاءٍ مِنْ بَنِي سُلَيْمٍ\hadithno{7341}\hadithtrans{Narrated Anas:The Prophet (ﷺ) brought the Ansar and the Quraish people into alliance in my house at Medina, and he invoked Allah for one month against the tribe of Bani Sulaim in (the last rak`a of each compulsory) prayer}}
\hadithdefcmd{bukhari}{7342}{حَدَّثَنِي أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدٌ، عَنْ أَبِي بُرْدَةَ، قَالَ قَدِمْتُ الْمَدِينَةَ فَلَقِيَنِي عَبْدُ اللَّهِ بْنُ سَلاَمٍ فَقَالَ لِي انْطَلِقْ إِلَى الْمَنْزِلِ فَأَسْقِيَكَ فِي قَدَحٍ شَرِبَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم، وَتُصَلِّي فِي مَسْجِدٍ صَلَّى فِيهِ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَانْطَلَقْتُ مَعَهُ، فَسَقَانِي سَوِيقًا، وَأَطْعَمَنِي تَمْرًا، وَصَلَّيْتُ فِي مَسْجِدِهِ‏.‏\hadithno{7342}\hadithtrans{Narrated Abu Burda:When I arrived at Medina, `Abdullah bin Salam met me and said to me, "Accompany me to my house so that I may make you drink from a bowl from which Allah's Messenger (ﷺ) used to drink, and that you may offer prayer in the mosque in which the Prophet (ﷺ) used to pray." I accompanied him, and he made me drink Sawiq and gave me dates to eat, and then I prayed in his mosque}}
\hadithdefcmd{bukhari}{7343}{حَدَّثَنَا سَعِيدُ بْنُ الرَّبِيعِ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنِي عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ عُمَرَ ـ رضى الله عنه ـ حَدَّثَهُ قَالَ حَدَّثَنِي النَّبِيُّ صلى الله عليه وسلم قَالَ ‏ "‏ أَتَانِي اللَّيْلَةَ آتٍ مِنْ رَبِّي وَهْوَ بِالْعَقِيقِ أَنْ صَلِّ فِي هَذَا الْوَادِي الْمُبَارَكِ وَقُلْ عُمْرَةٌ وَحَجَّةٌ ‏"‏‏.‏ وَقَالَ هَارُونُ بْنُ إِسْمَاعِيلَ حَدَّثَنَا عَلِيٌّ عُمْرَةٌ فِي حَجَّةٍ‏.‏\hadithno{7343}\hadithtrans{Narrated `Umar:The Prophet (ﷺ) said to me, "Someone came to me tonight from my Lord while I was in the 'Aqiq (valley), and said to me, "Offer prayer in this blessed valley and say: 'Labbaik' for the (performance of) `Umra and Hajj}}
\hadithdefcmd{bukhari}{7344}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، وَقَّتَ النَّبِيُّ صلى الله عليه وسلم قَرْنًا لأَهْلِ نَجْدٍ، وَالْجُحْفَةَ لأَهْلِ الشَّأْمِ، وَذَا الْحُلَيْفَةِ لأَهْلِ الْمَدِينَةِ‏.‏ قَالَ سَمِعْتُ هَذَا مِنَ النَّبِيِّ صلى الله عليه وسلم وَبَلَغَنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ وَلأَهْلِ الْيَمَنِ يَلَمْلَمُ ‏"‏‏.‏ وَذُكِرَ الْعِرَاقُ فَقَالَ لَمْ يَكُنْ عِرَاقٌ يَوْمَئِذٍ‏.‏\hadithno{7344}\hadithtrans{Narrated `Abdullah bin Dinar:Ibn `Umar said, "The Prophet (ﷺ) fixed Qarn as the Miqat (for assuming the Ihram) for the people of Najd, and Al-Juhfa for the people of Sham, and Dhul-Hulaifa for the people of Medina." Ibn `Umar added, "I heard this from the Prophet, and I have been informed that the Prophet (ﷺ) said, 'The Miqat for the Yemenites is Yalamlam.' "When Iraq was mentioned, he said, "At that time it was not a Muslim country}}
\hadithdefcmd{bukhari}{7345}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا الْفُضَيْلُ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أُرِيَ وَهْوَ فِي مُعَرَّسِهِ بِذِي الْحُلَيْفَةِ فَقِيلَ لَهُ إِنَّكَ بِبَطْحَاءَ مُبَارَكَةٍ‏.‏\hadithno{7345}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) had a dream in the last portion of the night when he was sleeping at Dhul-Hulaifa. (I n the dream) it was said to him, "You are in a blessed Batha' (i.e., valley)}}
\hadithdefcmd{bukhari}{7346}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فِي صَلاَةِ الْفَجْرِ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏"‏ اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ فِي الأَخِيرَةِ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ الْعَنْ فُلاَنًا وَفُلاَنًا ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ أَوْ يَتُوبَ عَلَيْهِمْ أَوْ يُعَذِّبَهُمْ فَإِنَّهُمْ ظَالِمُونَ‏\}‏‏.‏\hadithno{7346}\hadithtrans{Narrated Ibn `Umar:That he heard the Prophet, after raising his head from the bowing in morning prayer, saying, "O Allah, our Lord! All the praises are for you." And in the last (rak`a) he said, "O Allah! Curse so-and-so and so--and-so." And then Allah revealed:-- 'Not for you (O Muhammad) is the decision, (but for Allah), whether He turns in mercy to them or punish them, for they are indeed wrongdoers}}
\hadithdefcmd{bukhari}{7347}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح حَدَّثَنِي مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا عَتَّابُ بْنُ بَشِيرٍ، عَنْ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَرَقَهُ وَفَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُمْ ‏"‏ أَلاَ تُصَلُّونَ ‏"‏‏.‏ فَقَالَ عَلِيٌّ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا أَنْفُسُنَا بِيَدِ اللَّهِ، فَإِذَا شَاءَ أَنْ يَبْعَثَنَا بَعَثَنَا، فَانْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قَالَ لَهُ ذَلِكَ وَلَمْ يَرْجِعْ إِلَيْهِ شَيْئًا، ثُمَّ سَمِعَهُ وَهْوَ مُدْبِرٌ يَضْرِبُ فَخِذَهُ وَهْوَ يَقُولُ ‏\{‏وَكَانَ الإِنْسَانُ أَكْثَرَ شَىْءٍ جَدَلاً‏\}‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ يُقَالُ مَا أَتَاكَ لَيْلاً فَهْوَ طَارِقٌ‏.‏ وَيُقَالُ الطَّارِقُ النَّجْمُ، وَالثَّاقِبُ الْمُضِيءُ، يُقَالُ أَثْقِبْ نَارَكَ لِلْمُوقِدِ‏.‏\hadithno{7347}\hadithtrans{Narrated `Ali bin Abi Talib:That Allah's Messenger (ﷺ) came to him and Fatima the daughter of Allah's Messenger (ﷺ) at their house at night and said, "Won't you pray?" `Ali replied, "O Allah's Messenger (ﷺ)! Our souls are in the Hands of Allah and when he wants us to get up, He makes us get up." When `Ali said that to him, Allah's Messenger (ﷺ) left without saying anything to him. While the Prophet (ﷺ) was leaving, `Ali heard him striking his thigh (with his hand) and saying, "But man is quarrelsome more than anything else}}
\hadithdefcmd{bukhari}{7348}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَا نَحْنُ فِي الْمَسْجِدِ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْطَلِقُوا إِلَى يَهُودَ ‏"‏‏.‏ فَخَرَجْنَا مَعَهُ حَتَّى جِئْنَا بَيْتَ الْمِدْرَاسِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَنَادَاهُمْ فَقَالَ ‏"‏ يَا مَعْشَرَ يَهُودَ أَسْلِمُوا تَسْلَمُوا ‏"‏‏.‏ فَقَالُوا بَلَّغْتَ يَا أَبَا الْقَاسِمِ‏.‏ قَالَ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ أُرِيدُ أَسْلِمُوا تَسْلَمُوا ‏"‏‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ أُرِيدُ ‏"‏‏.‏ ثُمَّ قَالَهَا الثَّالِثَةَ فَقَالَ ‏"‏ اعْلَمُوا أَنَّمَا الأَرْضُ لِلَّهِ وَرَسُولِهِ وَإِنِّي أُرِيدُ أَنْ أُجْلِيَكُمْ مِنْ هَذِهِ الأَرْضِ، فَمَنْ وَجَدَ مِنْكُمْ بِمَالِهِ شَيْئًا فَلْيَبِعْهُ، وَإِلاَّ فَاعْلَمُوا أَنَّمَا الأَرْضُ لِلَّهِ وَرَسُولِهِ ‏"‏‏.‏\hadithno{7348}\hadithtrans{Narrated Abu Huraira:While we were in the mosque, Allah's Messenger (ﷺ) came out and said, "Let us proceed to the Jews." So we went out with him till we came to Bait-al-Midras. The Prophet (ﷺ) stood up there and called them, saying, "O assembly of Jews! Surrender to Allah (embrace Islam) and you will be safe!" They said, "You have conveyed Allah's message, O Aba-al-Qasim" Allah's Messenger (ﷺ) then said to them, "That is what I want; embrace Islam and you will be safe." They said, "You have conveyed the message, O Aba-al- Qasim." Allah's Messenger (ﷺ) then said to them, "That is what I want," and repeated his words for the third time and added, "Know that the earth is for Allah and I want to exile you from this land, so whoever among you has property he should sell it, otherwise, know that the land is for Allah and His Apostle}}
\hadithdefcmd{bukhari}{7349}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُجَاءُ بِنُوحٍ يَوْمَ الْقِيَامَةِ فَيُقَالُ لَهُ هَلْ بَلَّغْتَ فَيَقُولُ نَعَمْ يَا رَبِّ‏.‏ فَتُسْأَلُ أُمَّتُهُ هَلْ بَلَّغَكُمْ فَيَقُولُونَ مَا جَاءَنَا مِنْ نَذِيرٍ‏.‏ فَيَقُولُ مَنْ شُهُودُكَ فَيَقُولُ مُحَمَّدٌ وَأُمَّتُهُ‏.‏ فَيُجَاءُ بِكُمْ فَتَشْهَدُونَ ‏"‏‏.‏ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏وَكَذَلِكَ جَعَلْنَاكُمْ أُمَّةً وَسَطًا‏\}‏ قَالَ عَدْلاً ‏\{‏لِتَكُونُوا شُهَدَاءَ عَلَى النَّاسِ وَيَكُونَ الرَّسُولُ عَلَيْكُمْ شَهِيدًا‏\}‏ وَعَنْ جَعْفَرِ بْنِ عَوْنٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏\hadithno{7349}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "Noah will be brought (before Allah) on the Day of Resurrection, and will be asked, 'Did you convey the message of Allah?" He will reply, 'Yes, O Lord.' And then Noah's nation will be asked, 'Did he (Noah) convey Allah's message to you?' They will reply, 'No warner came to us.' Then Noah will be asked, 'Who are your witnesses?' He will reply. '(My witnesses are) Muhammad and his followers.' Thereupon you (Muslims) will be brought and you will bear witness." Then the Prophet (ﷺ) recited: 'And thus We have made of you (Muslims) a just and the best nation, that you might be witness over the nations, and the Apostle a witness over you}}
\hadithdefcmd{bukhari}{7351}{حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَخِيهِ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يُحَدِّثُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، وَأَبَا، هُرَيْرَةَ حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَخَا بَنِي عَدِيٍّ الأَنْصَارِيَّ وَاسْتَعْمَلَهُ عَلَى خَيْبَرَ، فَقَدِمَ بِتَمْرٍ جَنِيبٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّا لَنَشْتَرِي الصَّاعَ بِالصَّاعَيْنِ مِنَ الْجَمْعِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَفْعَلُوا، وَلَكِنْ مِثْلاً بِمِثْلٍ، أَوْ بِيعُوا هَذَا وَاشْتَرُوا بِثَمَنِهِ مِنْ هَذَا وَكَذَلِكَ الْمِيزَانُ ‏"‏‏.‏\hadithno{7351}\hadithtrans{Narrated Abu Sa`id Al-Khudri and Abu Huraira:Allah's Messenger (ﷺ) sent the brother of the tribe of Bani Adi Al-Ansari as governor of Khaibar. Then the man returned, bringing Janib (a good kind of date). Allah's Messenger (ﷺ) asked him, "Are all the dates of Khaibar like that?" He replied, "No, by Allah, O Allah's Messenger (ﷺ)! We take one Sa' of these (good) dates for two Sas of mixed dates." Allah's Messenger (ﷺ) then said, "Do not do so. You should either take one Sa of this (kind) for one Sa' of the other; or sell one kind and then buy with its price the other kind (of dates), and you should do the same in weighing}}
\hadithdefcmd{bukhari}{7352}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، حَدَّثَنِي يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي قَيْسٍ، مَوْلَى عَمْرِو بْنِ الْعَاصِ عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا حَكَمَ الْحَاكِمُ فَاجْتَهَدَ ثُمَّ أَصَابَ فَلَهُ أَجْرَانِ، وَإِذَا حَكَمَ فَاجْتَهَدَ ثُمَّ أَخْطَأَ فَلَهُ أَجْرٌ ‏"‏‏.‏ قَالَ فَحَدَّثْتُ بِهَذَا الْحَدِيثِ أَبَا بَكْرِ بْنَ عَمْرِو بْنِ حَزْمٍ فَقَالَ هَكَذَا حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ‏.‏ وَقَالَ عَبْدُ الْعَزِيزِ بْنُ الْمُطَّلِبِ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِي سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{7352}\hadithtrans{Narrated `Amr bin Al-`As:That he heard Allah's Messenger (ﷺ) saying, "If a judge gives a verdict according to the best of his knowledge and his verdict is correct (i.e. agrees with Allah and His Apostle's verdict) he will receive a double reward, and if he gives a verdict according to the best of his knowledge and his verdict is wrong, (i.e. against that of Allah and His Apostle) even then he will get a reward}}
\hadithdefcmd{bukhari}{7353}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي عَطَاءٌ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، قَالَ اسْتَأْذَنَ أَبُو مُوسَى عَلَى عُمَرَ فَكَأَنَّهُ وَجَدَهُ مَشْغُولاً فَرَجَعَ، فَقَالَ عُمَرُ أَلَمْ أَسْمَعْ صَوْتَ عَبْدِ اللَّهِ بْنِ قَيْسٍ، ائْذَنُوا لَهُ‏.‏ فَدُعِيَ لَهُ فَقَالَ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ فَقَالَ إِنَّا كُنَّا نُؤْمَرُ بِهَذَا‏.‏ قَالَ فَأْتِنِي عَلَى هَذَا بِبَيِّنَةٍ أَوْ لأَفْعَلَنَّ بِكَ‏.‏ فَانْطَلَقَ إِلَى مَجْلِسٍ مِنَ الأَنْصَارِ فَقَالُوا لاَ يَشْهَدُ إِلاَّ أَصَاغِرُنَا‏.‏ فَقَامَ أَبُو سَعِيدٍ الْخُدْرِيُّ فَقَالَ قَدْ كُنَّا نُؤْمَرُ بِهَذَا‏.‏ فَقَالَ عُمَرُ خَفِيَ عَلَىَّ هَذَا مِنْ أَمْرِ النَّبِيِّ صلى الله عليه وسلم، أَلْهَانِي الصَّفْقُ بِالأَسْوَاقِ‏.‏\hadithno{7353}\hadithtrans{Narrated 'Ubai bin `Umar:Abu Musa asked permission to enter upon `Umar, but seeing that he was busy, he went away. `Umar then said, "Didn't I hear the voice of `Abdullah bin Qais? Allow him to come in." He was called in and `Umar said to him, "What made you do what you did." He replied, "We have been instructed thus by the Prophet" `Umar said, "Bring proof (witness) for this, other wise I will do so-and-so to you." Then `Abdullah bin Qais went to a gathering of the Ansar who then said, "None but the youngest of us will give the witness for it." So Abu Sa`id Al-Khudri got up and said, "We used to be instructed thus (by the Prophet)." `Umar said, "This tradition of the Prophet (ﷺ) remained hidden from me. Business in the market kept me busy}}
\hadithdefcmd{bukhari}{7354}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي الزُّهْرِيُّ، أَنَّهُ سَمِعَهُ مِنَ الأَعْرَجِ، يَقُولُ أَخْبَرَنِي أَبُو هُرَيْرَةَ، قَالَ إِنَّكُمْ تَزْعُمُونَ أَنَّ أَبَا هُرَيْرَةَ، يُكْثِرُ الْحَدِيثَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَاللَّهُ الْمَوْعِدُ، إِنِّي كُنْتُ امْرَأً مِسْكِينًا أَلْزَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى مِلْءِ بَطْنِي، وَكَانَ الْمُهَاجِرُونَ يَشْغَلُهُمُ الصَّفْقُ بِالأَسْوَاقِ، وَكَانَتِ الأَنْصَارُ يَشْغَلُهُمُ الْقِيَامُ عَلَى أَمْوَالِهِمْ، فَشَهِدْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ وَقَالَ ‏ "‏ مَنْ يَبْسُطْ رِدَاءَهُ حَتَّى أَقْضِيَ مَقَالَتِي ثُمَّ يَقْبِضْهُ، فَلَنْ يَنْسَى شَيْئًا سَمِعَهُ مِنِّي ‏"‏‏.‏ فَبَسَطْتُ بُرْدَةً كَانَتْ عَلَىَّ، فَوَالَّذِي بَعَثَهُ بِالْحَقِّ مَا نَسِيتُ شَيْئًا سَمِعْتُهُ مِنْهُ‏.‏\hadithno{7354}\hadithtrans{Narrated Al-A'raj:Abu Huraira said, "You people claim that Abu Huraira narrates many narrations of Allah's Messenger (ﷺ). (Anyhow) with Allah will be our appointment. I was a poor man, and used to stick to Allah's Messenger (ﷺ) contented with what will fill my stomach, and the Muhajirin (emigrants) used to be busy trading in the markets, and the Ansar used to be busy looking after their properties. One-day I heard Allah's Messenger (ﷺ) saying, 'Who will spread his Rida' (a garment covering the upper part of the body) till I finished my speech and then fold it, (i.e. wrap it over your body), in which case he will never forget anything he had heard from me." So I spread my garment which I was wearing; and by Him Who sent Muhammad with the Truth, ever since, I have never forgotten whatever I heard from him (the Prophet)" (See, Hadith No. 119, Vol)}}
\hadithdefcmd{bukhari}{7355}{حَدَّثَنَا حَمَّادُ بْنُ حُمَيْدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ رَأَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يَحْلِفُ بِاللَّهِ أَنَّ ابْنَ الصَّائِدِ الدَّجَّالُ، قُلْتُ تَحْلِفُ بِاللَّهِ‏.‏ قَالَ إِنِّي سَمِعْتُ عُمَرَ يَحْلِفُ عَلَى ذَلِكَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يُنْكِرْهُ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{7355}\hadithtrans{Narrated Muhammad bin Al-Munkadir:I saw Jabir bin `Abdullah swearing by Allah that Ibn Sayyad was the Dajjal. I said to Jabir, "How can you swear by Allah?" Jabir said, "I have heard `Umar swearing by Allah regarding this matter in the presence of the Prophet (ﷺ) and the Prophet (ﷺ) did not disapprove of it}}
\hadithdefcmd{bukhari}{7356}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِثَلاَثَةٍ لِرَجُلٍ أَجْرٌ، وَلِرَجُلٍ سِتْرٌ، وَعَلَى رَجُلٍ وِزْرٌ، فَأَمَّا الَّذِي لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ فَأَطَالَ فِي مَرْجٍ أَوْ رَوْضَةٍ، فَمَا أَصَابَتْ فِي طِيَلِهَا ذَلِكَ الْمَرْجِ وَالرَّوْضَةِ كَانَ لَهُ حَسَنَاتٍ، وَلَوْ أَنَّهَا قَطَعَتْ طِيَلَهَا فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كَانَتْ آثَارُهَا وَأَرْوَاثُهَا حَسَنَاتٍ لَهُ، وَلَوْ أَنَّهَا مَرَّتْ بِنَهَرٍ فَشَرِبَتْ مِنْهُ وَلَمْ يُرِدْ أَنْ يَسْقِيَ بِهِ كَانَ ذَلِكَ حَسَنَاتٍ لَهُ، وَهِيَ لِذَلِكَ الرَّجُلِ أَجْرٌ، وَرَجُلٌ رَبَطَهَا تَغَنِّيًا وَتَعَفُّفًا وَلَمْ يَنْسَ حَقَّ اللَّهِ فِي رِقَابِهَا وَلاَ ظُهُورِهَا، فَهْىَ لَهُ سِتْرٌ، وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِيَاءً، فَهِيَ عَلَى ذَلِكَ وِزْرٌ ‏"‏‏.‏ وَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحُمُرِ قَالَ ‏"‏ مَا أَنْزَلَ اللَّهُ عَلَىَّ فِيهَا إِلاَّ هَذِهِ الآيَةَ الْفَاذَّةَ الْجَامِعَةَ ‏\{‏فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ‏\}‏‏"‏\hadithno{7356}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Horses may be used for three purposes: For a man they may be a source of reward (in the Hereafter); for another, a means of protection; and for another, a source of sin. The man for whom they are a source of reward, is the one who keeps them for Allah's Cause and ties them with long ropes and lets them graze in a pasture or garden. Whatever those long ropes allow them to eat of that pasture or garden, will be written as good deeds for him and if they break their ropes and run one or two rounds, then all their footsteps and dung will be written as good deeds for him, and if they pass a river and drink from it though he has had no intention of watering them, even then, that will be written as good deeds for him. So such horses are a source of reward for that man. For the man who keeps horses for his livelihood in order not to ask others for help or beg his bread, and at the same time he does not forget Allah's right of what he earns through them and of their backs (that he presents it to be used in Allah's Cause), such horses are a shelter for him (from poverty). For the man who keeps them just out of pride and for showing off, they are a source of sin." Then Allah's Messenger (ﷺ) was asked about donkeys. He said, "Allah has not revealed anything to me regarding them except this comprehensive Verse: "Then anyone who has done good, equal to the weight of an atom (or a small ant) shall see it, and any one who has done evil, equal to the weight of an atom (or a small ant) shall see it}}
\hadithdefcmd{bukhari}{7357}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ مَنْصُورِ بْنِ صَفِيَّةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم‏.‏ حَدَّثَنَا مُحَمَّدٌ ـ هُوَ ابْنُ عُقْبَةَ ـ حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ النُّمَيْرِيُّ الْبَصْرِيُّ حَدَّثَنَا مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ ابْنُ شَيْبَةَ حَدَّثَتْنِي أُمِّي عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ امْرَأَةً سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنِ الْحَيْضِ كَيْفَ تَغْتَسِلُ مِنْهُ قَالَ ‏"‏ تَأْخُذِينَ فِرْصَةً مُمَسَّكَةً فَتَوَضَّئِينَ بِهَا ‏"‏‏.‏ قَالَتْ كَيْفَ أَتَوَضَّأُ بِهَا يَا رَسُولَ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَوَضَّئِي ‏"‏‏.‏ قَالَتْ كَيْفَ أَتَوَضَّأُ بِهَا يَا رَسُولَ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَوَضَّئِينَ بِهَا ‏"‏‏.‏ قَالَتْ عَائِشَةُ فَعَرَفْتُ الَّذِي يُرِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَذَبْتُهَا إِلَىَّ فَعَلَّمْتُهَا‏.‏\hadithno{7357}\hadithtrans{Narrated `Aisha:A woman asked the Prophet (Hadith 456). Narrated `Aisha: A woman asked the Prophet (ﷺ) about the periods: How to take a bath after the periods. He said, "Take a perfumed piece of cloth and clean yourself with it." She said,' "How shall I clean myself with it, O Allah's Messenger (ﷺ)?" The Prophet (ﷺ) said, "Clean yourself" She said again, "How shall I clean myself, O Allah's Messenger (ﷺ)?" The Prophet (ﷺ) said, "Clean yourself with it." Then I knew what Allah's Messenger (ﷺ) meant. So I pulled her aside and explained it to her}}
\hadithdefcmd{bukhari}{7358}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ أُمَّ حُفَيْدٍ بِنْتَ الْحَارِثِ بْنِ حَزْنٍ، أَهْدَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم سَمْنًا وَأَقِطًا وَأَضُبًّا، فَدَعَا بِهِنَّ النَّبِيُّ صلى الله عليه وسلم فَأُكِلْنَ عَلَى مَائِدَتِهِ، فَتَرَكَهُنَّ النَّبِيُّ صلى الله عليه وسلم كَالْمُتَقَذِّرِ لَهُ، وَلَوْ كُنَّ حَرَامًا مَا أُكِلْنَ عَلَى مَائِدَتِهِ، وَلاَ أَمَرَ بِأَكْلِهِنَّ‏.‏\hadithno{7358}\hadithtrans{Narrated Ibn `Abbas:Um Hufaid bint Al-Harith bin Hazn presented the Prophet (ﷺ) with some butter, dried yoghurt (curd milk) and mastigures as a gift. The Prophet (ﷺ) then asked for a meal (mastigures etc. to be put) and it was eaten over his table cloth, but the Prophet (ﷺ) did not eat of it, as he had aversion to it. But if it had been illegal to eat, it would not have been eaten over his table cloth nor would he have ordered that (mastigures meat) to be eaten}}
\hadithdefcmd{bukhari}{7359}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ أَكَلَ ثُومًا أَوْ بَصَلاً، فَلْيَعْتَزِلْنَا أَوْ لِيَعْتَزِلْ مَسْجِدَنَا، وَلْيَقْعُدْ فِي بَيْتِهِ ‏"‏‏.‏ وَإِنَّهُ أُتِيَ بِبَدْرٍ ـ قَالَ ابْنُ وَهْبٍ يَعْنِي طَبَقًا ـ فِيهِ خَضِرَاتٌ مِنْ بُقُولٍ، فَوَجَدَ لَهَا رِيحًا فَسَأَلَ عَنْهَا ـ أُخْبِرَ بِمَا فِيهَا مِنَ الْبُقُولِ ـ فَقَالَ قَرِّبُوهَا فَقَرَّبُوهَا إِلَى بَعْضِ أَصْحَابِهِ كَانَ مَعَهُ، فَلَمَّا رَآهُ كَرِهَ أَكْلَهَا قَالَ ‏"‏ كُلْ، فَإِنِّي أُنَاجِي مَنْ لاَ تُنَاجِي ‏"‏‏.‏ وَقَالَ ابْنُ عُفَيْرٍ عَنِ ابْنِ وَهْبٍ بِقِدْرٍ فِيهِ خَضِرَاتٌ‏.‏ وَلَمْ يَذْكُرِ اللَّيْثُ وَأَبُو صَفْوَانَ عَنْ يُونُسَ قِصَّةَ الْقِدْرِ، فَلاَ أَدْرِي هُوَ مِنْ قَوْلِ الزُّهْرِيِّ أَوْ فِي الْحَدِيثِ‏.‏\hadithno{7359}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "Whoever has eaten garlic or onion, should keep away from us, or should keep away from our mosque and should stay at home." Ibn Wahb said, "Once a plate full of cooked vegetables was brought to the Prophet (ﷺ) at Badr. Detecting a bad smell from it, he asked about the dish and was informed of the kinds of vegetables in contained. He then said, "Bring it near," and so it was brought near to one of his companions who was with him. When the Prophet (ﷺ) saw it, he disliked eating it and said (to his companion), "Eat, for I talk in secret to ones whom you do not talk to}}
\hadithdefcmd{bukhari}{7360}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي وَعَمِّي، قَالاَ حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، أَخْبَرَنِي مُحَمَّدُ بْنُ جُبَيْرٍ، أَنَّ أَبَاهُ، جُبَيْرَ بْنَ مُطْعِمٍ أَخْبَرَهُ أَنَّ امْرَأَةً أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَلَّمَتْهُ فِي شَىْءٍ، فَأَمَرَهَا بِأَمْرٍ فَقَالَتْ أَرَأَيْتَ يَا رَسُولَ اللَّهِ إِنْ لَمْ أَجِدْكَ قَالَ ‏ "‏ إِنْ لَمْ تَجِدِينِي فَأْتِي أَبَا بَكْرٍ ‏"‏‏.‏ زَادَ الْحُمَيْدِيُّ عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ كَأَنَّهَا تَعْنِي الْمَوْتَ‏.‏\hadithno{7360}\hadithtrans{Narrated Jubair bin Mut`im:A lady came to Allah's Messenger (ﷺ) and she talked to him about something, and he gave her some order. She said, "O Allah's Messenger (ﷺ)! If I should not find you?" He said, "If you should not find me, then go to Abu Bakr." Ibrahim bin Sa`d said, "As if she meant the death (of the Prophet)}}
\hadithdefcmd{bukhari}{7361}{وَقَالَ أَبُو الْيَمَانِ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، سَمِعَ مُعَاوِيَةَ، يُحَدِّثُ رَهْطًا مِنْ قُرَيْشٍ بِالْمَدِينَةِ، وَذَكَرَ كَعْبَ الأَحْبَارِ فَقَالَ إِنْ كَانَ مِنْ أَصْدَقِ هَؤُلاَءِ الْمُحَدِّثِينَ الَّذِينَ يُحَدِّثُونَ عَنْ أَهْلِ الْكِتَابِ، وَإِنْ كُنَّا مَعَ ذَلِكَ لَنَبْلُو عَلَيْهِ الْكَذِبَ‏.‏\hadithno{7361}\hadithtrans{Narrated Humaid bin 'Abdur-Rahman that he heard Mu'awiya talking to a group of people from Quraish at Al-Madina, and on mentioning Ka'b Al-Ashbar, he said, "He was one of the most truthful of those who used to talk about the people of the Scripture, yet we used to detect certain faults in his information}}
\hadithdefcmd{bukhari}{7362}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ أَهْلُ الْكِتَابِ يَقْرَءُونَ التَّوْرَاةَ بِالْعِبْرَانِيَّةِ وَيُفَسِّرُونَهَا بِالْعَرَبِيَّةِ لأَهْلِ الإِسْلاَمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُصَدِّقُوا أَهْلَ الْكِتَابِ، وَلاَ تُكَذِّبُوهُمْ وَقُولُوا ‏\{‏آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ إِلَيْنَا وَمَا أُنْزِلَ إِلَيْكُمْ‏\}‏ ‏"‏‏.‏ الآيَةَ‏.‏\hadithno{7362}\hadithtrans{Narrated Abu Huraira:The people of the Book used to read the Torah in Hebrew and then explain it in Arabic to the Muslims. Allah's Messenger (ﷺ) said (to the Muslims). "Do not believe the people of the Book, nor disbelieve them, but say, 'We believe in Allah and whatever is revealed to us, and whatever is revealed to you}}
\hadithdefcmd{bukhari}{7363}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ، أَنَّ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَيْفَ تَسْأَلُونَ أَهْلَ الْكِتَابِ عَنْ شَىْءٍ، وَكِتَابُكُمُ الَّذِي أُنْزِلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَحْدَثُ، تَقْرَءُونَهُ مَحْضًا لَمْ يُشَبْ وَقَدْ حَدَّثَكُمْ أَنَّ أَهْلَ الْكِتَابِ بَدَّلُوا كِتَابَ اللَّهِ وَغَيَّرُوهُ وَكَتَبُوا بِأَيْدِيهِمُ الْكِتَابَ وَقَالُوا هُوَ مِنْ عِنْدِ اللَّهِ‏.‏ لِيَشْتَرُوا بِهِ ثَمَنًا قَلِيلاً، أَلاَ يَنْهَاكُمْ مَا جَاءَكُمْ مِنَ الْعِلْمِ عَنْ مَسْأَلَتِهِمْ، لاَ وَاللَّهِ مَا رَأَيْنَا مِنْهُمْ رَجُلاً يَسْأَلُكُمْ عَنِ الَّذِي أُنْزِلَ عَلَيْكُمْ‏.‏\hadithno{7363}\hadithtrans{Narrated Ubaidullah:Ibn `Abbas said, "Why do you ask the people of the scripture about anything while your Book (Qur'an) which has been revealed to Allah's Messenger (ﷺ) is newer and the latest? You read it pure, undistorted and unchanged, and Allah has told you that the people of the scripture (Jews and Christians) changed their scripture and distorted it, and wrote the scripture with their own hands and said, 'It is from Allah,' to sell it for a little gain. Does not the knowledge which has come to you prevent you from asking them about anything? No, by Allah, we have never seen any man from them asking you regarding what has been revealed to you}}
\hadithdefcmd{bukhari}{7364}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سَلاَّمِ بْنِ أَبِي مُطِيعٍ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ جُنْدَبِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْرَءُوا الْقُرْآنَ مَا ائْتَلَفَتْ قُلُوبُكُمْ فَإِذَا اخْتَلَفْتُمْ فَقُومُوا عَنْهُ ‏"‏‏.‏ قَالَ أَبُو عَبْد اللَّهِ سَمِعَ عَبْدُ الرَّحْمَنِ سَلَّامًا\hadithno{7364}\hadithtrans{Narrated Jundab bin `Abdullah:Allah's Messenger (ﷺ) said, "Recite (and study) the Qur'an as long as you are in agreement as to its interpretation and meanings, but when you have differences regarding its interpretation and meanings, then you should stop reciting it (for the time being.) (See Hadith No 581, Vol)}}
\hadithdefcmd{bukhari}{7365}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ جُنْدَبِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اقْرَءُوا الْقُرْآنَ مَا ائْتَلَفَتْ عَلَيْهِ قُلُوبُكُمْ، فَإِذَا اخْتَلَفْتُمْ فَقُومُوا عَنْهُ ‏"‏‏.‏ وَقَالَ يَزِيدُ بْنُ هَارُونَ عَنْ هَارُونَ الأَعْوَرِ، حَدَّثَنَا أَبُو عِمْرَانَ، عَنْ جُنْدَبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7365}\hadithtrans{Narrated Jundab bin `Abdullah:Allah's Messenger (ﷺ) said, "Recite (and study) the Qur'an as long as your hearts are in agreement as to its meanings, but if you have differences as regards its meaning, stop reading it then}}
\hadithdefcmd{bukhari}{7366}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا حُضِرَ النَّبِيُّ صلى الله عليه وسلم ـ قَالَ وَفِي الْبَيْتِ رِجَالٌ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ ـ قَالَ ‏"‏ هَلُمَّ أَكْتُبْ لَكُمْ كِتَابًا لَنْ تَضِلُّوا بَعْدَهُ ‏"‏‏.‏ قَالَ عُمَرُ إِنَّ النَّبِيَّ صلى الله عليه وسلم غَلَبَهُ الْوَجَعُ وَعِنْدَكُمُ الْقُرْآنُ، فَحَسْبُنَا كِتَابُ اللَّهِ‏.‏ وَاخْتَلَفَ أَهْلُ الْبَيْتِ وَاخْتَصَمُوا، فَمِنْهُمْ مَنْ يَقُولُ قَرِّبُوا يَكْتُبْ لَكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم كِتَابًا لَنْ تَضِلُّوا بَعْدَهُ‏.‏ وَمِنْهُمْ مَنْ يَقُولُ مَا قَالَ عُمَرُ، فَلَمَّا أَكْثَرُوا اللَّغَطَ وَالاِخْتِلاَفَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قُومُوا عَنِّي ‏"‏‏.‏ قَالَ عُبَيْدُ اللَّهِ فَكَانَ ابْنُ عَبَّاسٍ يَقُولُ إِنَّ الرَّزِيَّةَ كُلَّ الرَّزِيَّةِ مَا حَالَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ أَنْ يَكْتُبَ لَهُمْ ذَلِكَ الْكِتَابَ مِنِ اخْتِلاَفِهِمْ وَلَغَطِهِمْ‏.‏\hadithno{7366}\hadithtrans{Narrated Ibn `Abbas:When the time of the death of the Prophet (ﷺ) approached while there were some men in the house, and among them was `Umar bin Al-Khatttab, the Prophet (ﷺ) said, "Come near let me write for you a writing after which you will never go astray." `Umar said, "The Prophet (ﷺ) is seriously ill, and you have the Qur'an, so Allah's Book is sufficient for us." The people in the house differed and disputed. Some of them said, "Come near so that Allah's Messenger (ﷺ) may write for you a writing after which you will not go astray," while some of them said what `Umar said. When they made much noise and differed greatly before the Prophet, he said to them, "Go away and leave me." Ibn `Abbas used to say, "It was a great disaster that their difference and noise prevented Allah's Messenger (ﷺ) from writing that writing for them}}
\hadithdefcmd{bukhari}{7367}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ جُرَيْجٍ، قَالَ عَطَاءٌ قَالَ جَابِرٌ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ مُحَمَّدُ بْنُ بَكْرٍ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، فِي أُنَاسٍ مَعَهُ قَالَ أَهْلَلْنَا أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْحَجِّ خَالِصًا لَيْسَ مَعَهُ عُمْرَةٌ ـ قَالَ عَطَاءٌ قَالَ جَابِرٌ ـ فَقَدِمَ النَّبِيُّ صلى الله عليه وسلم صُبْحَ رَابِعَةٍ مَضَتْ مِنْ ذِي الْحِجَّةِ فَلَمَّا قَدِمْنَا أَمَرَنَا النَّبِيُّ صلى الله عليه وسلم أَنْ نَحِلَّ وَقَالَ ‏"‏ أَحِلُّوا وَأَصِيبُوا مِنَ النِّسَاءِ ‏"‏‏.‏ قَالَ عَطَاءٌ قَالَ جَابِرٌ وَلَمْ يَعْزِمْ عَلَيْهِمْ وَلَكِنْ أَحَلَّهُنَّ لَهُمْ فَبَلَغَهُ أَنَّا نَقُولُ لَمَّا لَمْ يَكُنْ بَيْنَنَا وَبَيْنَ عَرَفَةَ إِلاَّ خَمْسٌ أَمَرَنَا أَنْ نَحِلَّ إِلَى نِسَائِنَا فَنَأْتِي عَرَفَةَ تَقْطُرُ مَذَاكِيرُنَا الْمَذْىَ قَالَ وَيَقُولُ جَابِرٌ بِيَدِهِ هَكَذَا وَحَرَّكَهَا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ قَدْ عَلِمْتُمْ أَنِّي أَتْقَاكُمْ لِلَّهِ وَأَصْدَقُكُمْ وَأَبَرُّكُمْ وَلَوْلاَ هَدْيِي لَحَلَلْتُ كَمَا تَحِلُّونَ فَحِلُّوا فَلَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ ‏"‏‏.‏ فَحَلَلْنَا وَسَمِعْنَا وَأَطَعْنَا‏.‏\hadithno{7367}\hadithtrans{Narrated Ata:I heard Jabir bin `Abdullah in a gathering saying, "We, the companions of Allah's Messenger (ﷺ) assumed the state of Ihram to perform only Hajj without `Umra." Jabir added, "The Prophet (ﷺ) arrived (at Mecca) on the fourth of Dhul-Hijja. And when we arrived (in Mecca) the Prophet (ﷺ) ordered us to finish the state of Ihram, saying, "Finish your Ihram and go to your wives (for sexual relation)." Jabir added, "The Prophet did not oblige us (to go to our wives) but he only made that legal for us. Then he heard that we were saying, "When there remains only five days between us and the Day of `Arafat he orders us to finish our Ihram by sleeping with our wives in which case we will proceed to `Arafat with our male organs dribbling with semen?' (Jabir pointed out with his hand illustrating what he was saying). Allah's Messenger (ﷺ) stood up and said, 'You (People) know that I am the most Allah-fearing, the most truthful and the best doer of good deeds (pious) from among you. If I had not brought the Hadi with me, I would have finished my Ihram as you will do, so finish your Ihram. If I had formerly known what I came to know lately, I would not have brought the Hadi with me.' So we finished our Ihram and listened to the Prophet (ﷺ) and obeyed him." (See Hadith No. 713, Vol)}}
\hadithdefcmd{bukhari}{7368}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، عَنِ ابْنِ بُرَيْدَةَ، حَدَّثَنِي عَبْدُ اللَّهِ الْمُزَنِيُّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلُّوا قَبْلَ صَلاَةِ الْمَغْرِبِ ـ قَالَ فِي الثَّالِثَةِ ـ لِمَنْ شَاءَ ‏"‏‏.‏ كَرَاهِيَةَ أَنْ يَتَّخِذَهَا النَّاسُ سُنَّةً‏.‏\hadithno{7368}\hadithtrans{Narrated `Abdullah Al Muzam:The Prophet (ﷺ) said, "Perform (an optional) prayer before Maghrib prayer." (He repeated it thrice) and the third time he said, "Whoever wants to offer it can do so," lest the people should take it as a Sunna (tradition). (See Hadith No. 277, Vol)}}
\hadithdefcmd{bukhari}{7369}{حَدَّثَنَا الأُوَيْسِيُّ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ، وَابْنُ الْمُسَيَّبِ، وَعَلْقَمَةُ بْنُ وَقَّاصٍ، وَعُبَيْدُ اللَّهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ قَالَتْ وَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ وَأُسَامَةَ بْنَ زَيْدٍ حِينَ اسْتَلْبَثَ الْوَحْىُ يَسْأَلُهُمَا، وَهْوَ يَسْتَشِيرُهُمَا فِي فِرَاقِ أَهْلِهِ، فَأَمَّا أُسَامَةُ فَأَشَارَ بِالَّذِي يَعْلَمُ مِنْ بَرَاءَةِ أَهْلِهِ، وَأَمَّا عَلِيٌّ فَقَالَ لَمْ يُضَيِّقِ اللَّهُ عَلَيْكَ، وَالنِّسَاءُ سِوَاهَا كَثِيرٌ، وَسَلِ الْجَارِيَةَ تَصْدُقْكَ‏.‏ فَقَالَ ‏"‏ هَلْ رَأَيْتِ مِنْ شَىْءٍ يَرِيبُكِ ‏"‏‏.‏ قَالَتْ مَا رَأَيْتُ أَمْرًا أَكْثَرَ مِنْ أَنَّهَا جَارِيَةٌ حَدِيثَةُ السِّنِّ تَنَامُ عَنْ عَجِينِ أَهْلِهَا فَتَأْتِي الدَّاجِنُ فَتَأْكُلُهُ‏.‏ فَقَامَ عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ يَا مَعْشَرَ الْمُسْلِمِينَ مَنْ يَعْذِرُنِي مِنْ رَجُلٍ بَلَغَنِي أَذَاهُ فِي أَهْلِي، وَاللَّهِ مَا عَلِمْتُ عَلَى أَهْلِي إِلاَّ خَيْرًا ‏"‏‏.‏ فَذَكَرَ بَرَاءَةَ عَائِشَةَ‏.‏ وَقَالَ أَبُو أُسَامَةَ عَنْ هِشَامٍ‏.‏\hadithno{7369}\hadithtrans{Narrated `Aisha:After the slanderers had given a forged statement against her, Allah's Messenger (ﷺ) called `Ali bin Abi Talib and Usama bin Zaid when the Divine Inspiration was delayed. He wanted to ask them and consult them about the question of divorcing me. Usama gave his evidence that was based on what he knew about my innocence, but `Ali said, "Allah has not put restrictions on you and there are many women other than her. Furthermore you may ask the slave girl who will tell you the truth." So the Prophet (ﷺ) asked Barira (my salve girl), "Have you seen anything that may arouse your suspicion?" She replied, "I have not seen anything more than that she is a little girl who sleeps, leaving the dough of her family (unguarded) that the domestic goats come and eat it." Then the Prophet (ﷺ) stood on the pulpit and said, "O Muslims! Who will help me against the man who has harmed me by slandering my wife? By Allah, I know nothing about my family except good." The narrator added: Then the Prophet (ﷺ) mentioned the innocence of `Aisha. (See Hadith No. 274, Vol)}}
\hadithdefcmd{bukhari}{7370}{حَدَّثَنِي مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي زَكَرِيَّاءَ الْغَسَّانِيُّ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ ‏ "‏ مَا تُشِيرُونَ عَلَىَّ فِي قَوْمٍ يَسُبُّونَ أَهْلِي مَا عَلِمْتُ عَلَيْهِمْ مِنْ سُوءٍ قَطُّ ‏"‏‏.‏ وَعَنْ عُرْوَةَ قَالَ لَمَّا أُخْبِرَتْ عَا��ِشَةُ بِالأَمْرِ قَالَتْ يَا رَسُولَ اللَّهِ أَتَأْذَنُ لِي أَنْ أَنْطَلِقَ إِلَى أَهْلِي‏.‏ فَأَذِنَ لَهَا وَأَرْسَلَ مَعَهَا الْغُلاَمَ‏.‏ وَقَالَ رَجُلٌ مِنَ الأَنْصَارِ سُبْحَانَكَ مَا يَكُونُ لَنَا أَنْ نَتَكَلَّمَ بِهَذَا، سُبْحَانَكَ هَذَا بُهْتَانٌ عَظِيمٌ‏.‏\hadithno{7370}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) addressed the people, and after praising and glorifying Allah, he said, "What do you suggest me regarding those people who are abusing my wife? I have never known anything bad about her." The sub-narrator, `Urwa, said: When `Aisha was told of the slander, she said, "O Allah's Apostle! Will you allow me to go to my parents' home?" He allowed her and sent a slave along with her. An Ansari man said, "Subhanaka! It is not right for us to speak about this. Subhanaka! This is a great lie}}
